diff --git a/kalzium/src/kalzium.cpp b/kalzium/src/kalzium.cpp
index 72fb8200..011aecb6 100644
--- a/kalzium/src/kalzium.cpp
+++ b/kalzium/src/kalzium.cpp
@@ -77,7 +77,7 @@ Kalzium::Kalzium()
connect( m_PerodicTableView, TQT_SIGNAL( ElementClicked( int ) ), TQT_TQOBJECT(this), TQT_SLOT( openInformationDialog( int ) ));
connect( m_PerodicTableView, TQT_SIGNAL( MouseOver( int ) ), TQT_TQOBJECT(this), TQT_SLOT( slotStatusbar( int ) ));
- // tqlayouting
+ // layouting
setCentralWidget( centralWidget );
centralWidget->show();
diff --git a/kalzium/src/kalziumdataobject.cpp b/kalzium/src/kalziumdataobject.cpp
index f25cbfc4..a759fee2 100644
--- a/kalzium/src/kalziumdataobject.cpp
+++ b/kalzium/src/kalziumdataobject.cpp
@@ -46,29 +46,29 @@ KalziumDataObject::KalziumDataObject()
KURL url;
url.setPath( locate("data", "kalzium/data/"));
url.setFileName( "data.xml" );
- TQFile tqlayoutFile( url.path() );
+ TQFile layoutFile( url.path() );
- if (!tqlayoutFile.exists())
+ if (!layoutFile.exists())
{
kdDebug() << "data.xml not found, exiting" << endl;
kapp->exit(0);
return;
}
- if (!tqlayoutFile.open(IO_ReadOnly))
+ if (!layoutFile.open(IO_ReadOnly))
{
kdDebug() << "data.xml IO-error" << endl;
return;
}
// Check if the document is well-formed
- if (!doc.setContent(&tqlayoutFile))
+ if (!doc.setContent(&layoutFile))
{
kdDebug() << "wrong xml" << endl;
- tqlayoutFile.close();
+ layoutFile.close();
return;
}
- tqlayoutFile.close();
+ layoutFile.close();
ElementList = readData( doc );
m_numOfElements = ElementList.count();
diff --git a/kalzium/src/kalziumtip.cpp b/kalzium/src/kalziumtip.cpp
index 794c9f25..e0e05388 100644
--- a/kalzium/src/kalziumtip.cpp
+++ b/kalzium/src/kalziumtip.cpp
@@ -139,7 +139,7 @@ void KalziumTip::display()
m_richText->setWidth(400);
- m_tqmaskEffect = isVisible() ? Plain : Dissolve;
+ m_maskEffect = isVisible() ? Plain : Dissolve;
m_dissolveSize = 24;
m_dissolveDelta = -1;
@@ -178,7 +178,7 @@ void KalziumTip::displayInternal()
resize(width, height);
// create and set transparency tqmask
- switch(m_tqmaskEffect)
+ switch(m_maskEffect)
{
case Plain:
plainMask();
@@ -218,20 +218,20 @@ void KalziumTip::displayInternal()
void KalziumTip::dissolveMask()
{
- TQPainter tqmaskPainter(&m_tqmask);
+ TQPainter maskPainter(&m_tqmask);
m_tqmask.fill(TQt::black);
- tqmaskPainter.setBrush(TQt::white);
- tqmaskPainter.setPen(TQt::white);
- tqmaskPainter.drawRoundRect(m_tqmask.rect(), 1600 / m_tqmask.rect().width(),
+ maskPainter.setBrush(TQt::white);
+ maskPainter.setPen(TQt::white);
+ maskPainter.drawRoundRect(m_tqmask.rect(), 1600 / m_tqmask.rect().width(),
1600 / m_tqmask.rect().height());
m_dissolveSize += m_dissolveDelta;
if (m_dissolveSize > 0)
{
- tqmaskPainter.setRasterOp(TQt::EraseROP);
+ maskPainter.setRasterOp(TQt::EraseROP);
int x, y, s;
const int size = 16;
@@ -247,7 +247,7 @@ void KalziumTip::dissolveMask()
{
s = 0;
}
- tqmaskPainter.drawEllipse(x - s / 2, y - s / 2, s, s);
+ maskPainter.drawEllipse(x - s / 2, y - s / 2, s, s);
}
}
}
@@ -269,13 +269,13 @@ void KalziumTip::hide()
void KalziumTip::plainMask()
{
- TQPainter tqmaskPainter(&m_tqmask);
+ TQPainter maskPainter(&m_tqmask);
m_tqmask.fill(TQt::black);
- tqmaskPainter.setBrush(TQt::white);
- tqmaskPainter.setPen(TQt::white);
- tqmaskPainter.drawRoundRect(m_tqmask.rect(), 1600 / m_tqmask.rect().width(),
+ maskPainter.setBrush(TQt::white);
+ maskPainter.setPen(TQt::white);
+ maskPainter.drawRoundRect(m_tqmask.rect(), 1600 / m_tqmask.rect().width(),
1600 / m_tqmask.rect().height());
setMask(m_tqmask);
m_frameTimer.stop();
diff --git a/kalzium/src/kalziumtip.h b/kalzium/src/kalziumtip.h
index 8c7b063a..761b6c86 100644
--- a/kalzium/src/kalziumtip.h
+++ b/kalzium/src/kalziumtip.h
@@ -73,7 +73,7 @@ class KalziumTip : public TQWidget
TQPixmap m_icon; //icon shown on the tip
TQPixmap m_noElemIcon; //icon for element wich have no image
- MaskEffect m_tqmaskEffect; //inidicates to show tqmask effect or plain
+ MaskEffect m_maskEffect; //inidicates to show tqmask effect or plain
TQSimpleRichText* m_richText;
int m_dissolveSize;
diff --git a/kalzium/src/molcalcwidgetbase.ui b/kalzium/src/molcalcwidgetbase.ui
index 63be9624..04760f0d 100644
--- a/kalzium/src/molcalcwidgetbase.ui
+++ b/kalzium/src/molcalcwidgetbase.ui
@@ -127,7 +127,7 @@
slotCalcButtonClicked()
-
+
klineedit.h
kpushbutton.h
diff --git a/kalzium/src/moleculeparser.cpp b/kalzium/src/moleculeparser.cpp
index b3d19120..6780e65e 100644
--- a/kalzium/src/moleculeparser.cpp
+++ b/kalzium/src/moleculeparser.cpp
@@ -172,7 +172,7 @@ MoleculeParser::parseSubmolecule(double *_resultMass,
// Parse a term within the molecule, i.e. a single atom or a
-// submolecule within tqparenthesis followed by an optional number.
+// submolecule within parenthesis followed by an optional number.
// Examples: Bk, Mn2, (COOH)2
//
// Return true if correct, otherwise return false.
diff --git a/kalzium/src/periodictableview.cpp b/kalzium/src/periodictableview.cpp
index 0e810aff..cb4282d4 100644
--- a/kalzium/src/periodictableview.cpp
+++ b/kalzium/src/periodictableview.cpp
@@ -741,7 +741,7 @@ void PerodicTableView::mouseMoveEvent( TQMouseEvent * /*mouse*/ )
//JH: only update() if we were showing a tooltip
if ( m_tooltipElementNumber || m_showLegendTooltip )
{
- //this tqinvalidates the number. If the mouse
+ //this invalidates the number. If the mouse
//is moved, the number is invalid.
m_tooltipElementNumber = 0;
m_showLegendTooltip = false;
diff --git a/kalzium/src/plotsetupwidget.ui b/kalzium/src/plotsetupwidget.ui
index 3fc89428..06ef3fa5 100644
--- a/kalzium/src/plotsetupwidget.ui
+++ b/kalzium/src/plotsetupwidget.ui
@@ -248,7 +248,7 @@
-
+
knuminput.h
kcombobox.h
diff --git a/kalzium/src/settings_colors.ui b/kalzium/src/settings_colors.ui
index da606dc2..1e025f4f 100644
--- a/kalzium/src/settings_colors.ui
+++ b/kalzium/src/settings_colors.ui
@@ -901,7 +901,7 @@
-
+
kcolorbutton.h
kcolorbutton.h
diff --git a/kalzium/src/settings_misc.ui b/kalzium/src/settings_misc.ui
index e5480d1a..0e88167d 100644
--- a/kalzium/src/settings_misc.ui
+++ b/kalzium/src/settings_misc.ui
@@ -67,5 +67,5 @@
-
+
diff --git a/kalzium/src/settings_units.ui b/kalzium/src/settings_units.ui
index e93bd9ca..4bf4031c 100644
--- a/kalzium/src/settings_units.ui
+++ b/kalzium/src/settings_units.ui
@@ -163,5 +163,5 @@
-
+
diff --git a/kalzium/src/somwidget.ui b/kalzium/src/somwidget.ui
index bdf953a5..057dc235 100644
--- a/kalzium/src/somwidget.ui
+++ b/kalzium/src/somwidget.ui
@@ -178,7 +178,7 @@ the state of matter
-
+
knuminput.h
diff --git a/kalzium/src/spectrum.h b/kalzium/src/spectrum.h
index 4d71837f..dcde91cb 100644
--- a/kalzium/src/spectrum.h
+++ b/kalzium/src/spectrum.h
@@ -145,7 +145,7 @@ class Spectrum
/**
* @return the tqparent element of this spectrum
*/
- Element* tqparentElement()
+ Element* parentElement()
{ return m_parentElement; }
private:
diff --git a/kalzium/src/spectrumview.ui b/kalzium/src/spectrumview.ui
index 39dd7f18..89204944 100644
--- a/kalzium/src/spectrumview.ui
+++ b/kalzium/src/spectrumview.ui
@@ -216,7 +216,7 @@
slotExportAsImage()
-
+
spectrumwidget.h
kpushbutton.h
diff --git a/kalzium/src/spectrumwidget.cpp b/kalzium/src/spectrumwidget.cpp
index 2431b407..4f487e64 100644
--- a/kalzium/src/spectrumwidget.cpp
+++ b/kalzium/src/spectrumwidget.cpp
@@ -415,9 +415,9 @@ TQPixmap SpectrumWidget::pixmap()
TQString text;
if( m_type == EmissionSpectrum )
- text = i18n( "Emission spectrum of %1" ).tqarg( m_spectrum->tqparentElement()->elname() );
+ text = i18n( "Emission spectrum of %1" ).tqarg( m_spectrum->parentElement()->elname() );
else
- text = i18n( "Absorption spectrum of %1" ).tqarg( m_spectrum->tqparentElement()->elname() );
+ text = i18n( "Absorption spectrum of %1" ).tqarg( m_spectrum->parentElement()->elname() );
TQPainter p( &tmp );
p.setPen( TQt::black );
diff --git a/kalzium/src/timewidget.ui b/kalzium/src/timewidget.ui
index b810b101..28ddf7a5 100644
--- a/kalzium/src/timewidget.ui
+++ b/kalzium/src/timewidget.ui
@@ -194,7 +194,7 @@ of the elements
setValue(int)
-
+
knuminput.h
diff --git a/kanagram/src/mainsettingswidget.ui b/kanagram/src/mainsettingswidget.ui
index cc7a5053..b8d29ccb 100644
--- a/kanagram/src/mainsettingswidget.ui
+++ b/kanagram/src/mainsettingswidget.ui
@@ -178,5 +178,5 @@
kcfg_hintHideTime
kcfg_useSounds
-
+
diff --git a/kanagram/src/newstuffwidget.ui b/kanagram/src/newstuffwidget.ui
index 1ec4d88c..55163cdd 100644
--- a/kanagram/src/newstuffwidget.ui
+++ b/kanagram/src/newstuffwidget.ui
@@ -58,5 +58,5 @@ the button to get new vocabulary files.
-
+
diff --git a/kanagram/src/vocabedit.cpp b/kanagram/src/vocabedit.cpp
index 2315faa4..7457265b 100644
--- a/kanagram/src/vocabedit.cpp
+++ b/kanagram/src/vocabedit.cpp
@@ -102,7 +102,7 @@ void VocabEdit::slotSave()
}
doc->saveAs(TQT_TQOBJECT(this), KURL(fileName), KEduVocDocument::automatic, "kanagram");
- VocabSettings *settings = (VocabSettings*)this->tqparentWidget();
+ VocabSettings *settings = (VocabSettings*)this->parentWidget();
settings->refreshView();
if(m_textChanged)
diff --git a/kanagram/src/vocabeditwidget.ui b/kanagram/src/vocabeditwidget.ui
index 8fbc00ba..8f9d6023 100644
--- a/kanagram/src/vocabeditwidget.ui
+++ b/kanagram/src/vocabeditwidget.ui
@@ -224,5 +224,5 @@
btnClose
lboxWords
-
+
diff --git a/kanagram/src/vocabsettingswidget.ui b/kanagram/src/vocabsettingswidget.ui
index f9832a71..71d754d8 100644
--- a/kanagram/src/vocabsettingswidget.ui
+++ b/kanagram/src/vocabsettingswidget.ui
@@ -113,5 +113,5 @@
createNew()
-
+
diff --git a/kbruch/src/taskvieweroptionsbase.ui b/kbruch/src/taskvieweroptionsbase.ui
index 860ffbfd..8938ac96 100644
--- a/kbruch/src/taskvieweroptionsbase.ui
+++ b/kbruch/src/taskvieweroptionsbase.ui
@@ -214,7 +214,7 @@
-
+
kfontdialog.h
kcolorbutton.h
diff --git a/keduca/keduca/configdialogbase.ui b/keduca/keduca/configdialogbase.ui
index 53872ecb..7eff82a8 100644
--- a/keduca/keduca/configdialogbase.ui
+++ b/keduca/keduca/configdialogbase.ui
@@ -96,5 +96,5 @@
-
+
diff --git a/keduca/keduca/keduca_part.cpp b/keduca/keduca/keduca_part.cpp
index 6b0e17aa..7a0f4326 100644
--- a/keduca/keduca/keduca_part.cpp
+++ b/keduca/keduca/keduca_part.cpp
@@ -34,14 +34,14 @@
typedef KParts::GenericFactory KEducaPartFactory;
K_EXPORT_COMPONENT_FACTORY( libkeducapart, KEducaPartFactory )
-KEducaPart::KEducaPart( TQWidget *tqparentWidget, const char *widgetName,
+KEducaPart::KEducaPart( TQWidget *parentWidget, const char *widgetName,
TQObject *tqparent, const char *name,
const TQStringList &/*args*/ )
: KParts::ReadOnlyPart( tqparent, name )
{
setInstance( KEducaPartFactory::instance() );
- m_view = new KEducaView( tqparentWidget, widgetName );
+ m_view = new KEducaView( parentWidget, widgetName );
m_view->show();
setWidget( m_view );
diff --git a/keduca/keduca/keduca_part.h b/keduca/keduca/keduca_part.h
index d19d597c..442ebbcd 100644
--- a/keduca/keduca/keduca_part.h
+++ b/keduca/keduca/keduca_part.h
@@ -41,7 +41,7 @@ class KEducaPart : public KParts::ReadOnlyPart
/*
* Constructor.
*/
- KEducaPart( TQWidget *tqparentWidget, const char *widgetName, TQObject *tqparent,
+ KEducaPart( TQWidget *parentWidget, const char *widgetName, TQObject *tqparent,
const char *name, const TQStringList &args );
/*
diff --git a/keduca/keducabuilder/kcontroladdeditbase.ui b/keduca/keducabuilder/kcontroladdeditbase.ui
index d2e74f68..c702ce3b 100644
--- a/keduca/keducabuilder/kcontroladdeditbase.ui
+++ b/keduca/keducabuilder/kcontroladdeditbase.ui
@@ -860,7 +860,7 @@
slotDataChanged()
slotAnswerSelected(TQListViewItem *)
-
+
kurlrequester.h
klineedit.h
diff --git a/keduca/keducabuilder/kcontrolheaderbase.ui b/keduca/keducabuilder/kcontrolheaderbase.ui
index 2cf47b6e..24dbbf09 100644
--- a/keduca/keducabuilder/kcontrolheaderbase.ui
+++ b/keduca/keducabuilder/kcontrolheaderbase.ui
@@ -459,7 +459,7 @@
buttonOk
buttonCancel
-
+
klineedit.h
klineedit.h
diff --git a/keduca/keducabuilder/keducaeditorstartdialogbase.ui b/keduca/keducabuilder/keducaeditorstartdialogbase.ui
index 57679cb3..c873a844 100644
--- a/keduca/keducabuilder/keducaeditorstartdialogbase.ui
+++ b/keduca/keducabuilder/keducaeditorstartdialogbase.ui
@@ -312,7 +312,7 @@
openDocumentRB
openRecentDocumentRB
-
+
klineedit.h
kpushbutton.h
diff --git a/keduca/libkeduca/kgallerydialogbase.ui b/keduca/libkeduca/kgallerydialogbase.ui
index b300cc2a..9a11d8b4 100644
--- a/keduca/libkeduca/kgallerydialogbase.ui
+++ b/keduca/libkeduca/kgallerydialogbase.ui
@@ -366,5 +366,5 @@
slotButtonAdd()
slotServerSelected(TQListViewItem*)
-
+
diff --git a/kgeography/Changelog b/kgeography/Changelog
index c4c23b7d..f54c280c 100644
--- a/kgeography/Changelog
+++ b/kgeography/Changelog
@@ -88,7 +88,7 @@
* RightWidget is really LeftWidget ¬.¬
* There is no need to store p_rightWidget as a class member
* Bump version to 0.2.1
- * Improve tqlayouting of mapasker
+ * Improve layouting of mapasker
* Make the scrollbar work also when clicking on the arrows
(sliderMoved -> valueChanged)
* Fix resizing bug in mapWidget that showed a inexistant part of the
diff --git a/khangman/khangman/advanced.ui b/khangman/khangman/advanced.ui
index 0e0948eb..7910fab7 100644
--- a/khangman/khangman/advanced.ui
+++ b/khangman/khangman/advanced.ui
@@ -91,5 +91,5 @@ For example, in Catalan, if this is unchecked and you type "o", the o and ò wil
-
+
diff --git a/khangman/khangman/normal.ui b/khangman/khangman/normal.ui
index 57921bd9..b7d3df2e 100644
--- a/khangman/khangman/normal.ui
+++ b/khangman/khangman/normal.ui
@@ -90,5 +90,5 @@ Default is no sound.
-
+
diff --git a/khangman/khangman/timerdlg.ui b/khangman/khangman/timerdlg.ui
index 9f51d442..dbd09dd7 100644
--- a/khangman/khangman/timerdlg.ui
+++ b/khangman/khangman/timerdlg.ui
@@ -221,7 +221,7 @@
-
+
kactivelabel.h
kactivelabel.h
diff --git a/kig/ChangeLog b/kig/ChangeLog
index 8c60c89f..3cbd6c2f 100644
--- a/kig/ChangeLog
+++ b/kig/ChangeLog
@@ -1142,7 +1142,7 @@
* Fix the moving system again, it now only redraws exactly those
objects that need to be redrawn. E.g. when a constrained point
- was moved, before it was assumed that all of its tqparents, and
+ was moved, before it was assumed that all of its parents, and
their tqchildren would move, whereas in reality, a constrained point
does not move the curve it is constrained to. This is now taken
into account for. This much optimizes the case where we move the
@@ -1200,7 +1200,7 @@
could not open.. I'm backporting this into Kig 0.6.0 and
informing the packager..
- * clean up: Objects now store their tqparents in order, so that no
+ * clean up: Objects now store their parents in order, so that no
parsing has to be done in the calc() function.. Also some more
modifications making that function a bit simpler are included.
Specifically, ArgsParser now does the checking of the arguments,
@@ -1218,7 +1218,7 @@
2003-09-01 Dominique Devriese
- * only move an object if its tqparents are not yet moving.. This
+ * only move an object if its parents are not yet moving.. This
fixes bug #63250.
* remove the defective operator| and operator& implementations for
diff --git a/kig/DESIGN b/kig/DESIGN
index 6d4a8c37..3c922c67 100644
--- a/kig/DESIGN
+++ b/kig/DESIGN
@@ -19,7 +19,7 @@ An ObjectImp represents the current state of an object in Kig. It
keeps information about what type of object it is ( e.g. a line, a
point, a circle etc. ), and its exact data ( e.g. the center and
radius of the circle ). It is *not* in any way aware of how the
-object was calculated from its tqparents (e.g. is this a line that is
+object was calculated from its parents (e.g. is this a line that is
constructed as the parallel of another line, or as the line going
through two given points ? ) or how it is drawn on the window (
e.g. the thickness of the line, its color etc. ).
@@ -50,21 +50,21 @@ calculating an ObjectImp from other ObjectImp's. It is also a node in
the dependency graph of a certain document. E.g. a LineImp can be
calculated from the two PointImp's it has to go through; every time
either of them moves, this calculation is redone. In this case, there
-would be an ObjectCalcer that keeps a reference to its two tqparents (
+would be an ObjectCalcer that keeps a reference to its two parents (
the ObjectCalcer's representing the points ), and that will calculate
its ObjectImp value every time it is asked to do so ( i.e. every time
-one of its tqparents moves.. ).
+one of its parents moves.. ).
Because of the complex relations that ObjectCalcer's hold to other
ObjectCalcer's and to other classes, they have been made
reference-counted. This means that they keep a count internally of
how much times a pointer to them is held. If this count reaches 0,
this means that nobody needs them anymore, and they delete themselves.
-E.g. an ObjectCalcer always keeps a reference to its tqparents, to
+E.g. an ObjectCalcer always keeps a reference to its parents, to
ensure that those aren't deleted before it is deleted.
In the inheritance graph of a document, the lowermost objects keep
-references to their tqparents and those keep reference to their tqparents,
+references to their parents and those keep reference to their parents,
so that all of the top of the graph is kept alive. Of course, someone
needs to keep a reference to the bottommost objects in the graph,
because otherwise, the entire graph would be deleted. As we will see
@@ -76,7 +76,7 @@ At the end of the program, this reference is released, and all the
objects are deleted.
A special case of an ObjectCalcer is the ObjectConstCalcer. This is
-an ObjectCalcer that has no tqparents, and only holds some data. The
+an ObjectCalcer that has no parents, and only holds some data. The
data is held as an ObjectImp of some type, and it will remain
constant, and no calculation needs to be done to get it, it is just
returned every time it is needed.
@@ -159,9 +159,9 @@ Most of this is handled by the TextType class.
2.1.2 TextType
The TextType class is an implementation of an ObjectType. It tqcontains
-code specifying how to calculate a TextImp from its tqparents, and for
+code specifying how to calculate a TextImp from its parents, and for
how it behaves on user input. A text object has at least three
-tqparents, and can handle any number of optional arguments. The three
+parents, and can handle any number of optional arguments. The three
mandatory arguments are an int, which is set to 1 or 0 depending on
whether the label needs a surrounding box, a PointImp, containing the
location of the text label, and a string containing the text of the
@@ -170,7 +170,7 @@ additional argument is used to replace the lowest-numbered of those
tokens, with its string representation. The function
ObjectImp::fillInNextEscape is used for this.
-For example, if a TextType has the following tqparents:
+For example, if a TextType has the following parents:
a IntImp with value 0
a PointImp with value (0,0)
a String with value "This segment is %1 units long."
@@ -197,7 +197,7 @@ proud of this design.
In the implementation of this, we use the concept of constrained
points. This is a point that is attached to a certain curve. It is
implemented in Kig by the ConstrainedPointType, which takes a CurveImp
-and a DoubleImp as tqparents and calculates a Point from these by using
+and a DoubleImp as parents and calculates a Point from these by using
the CurveImp::getPoint function.
2.2.2 The Implementation
@@ -213,7 +213,7 @@ smallest part of the hierarchy that contains all paths from the first
point to the second point. We then determine all objects that are not
*on* one of those paths ( meaning that they are not calculated from
the first point, or another object that is on one of those paths ),
-but that are tqparents of one or more objects that are on those paths.
+but that are parents of one or more objects that are on those paths.
I call this set of objects the "side of the path" sometimes in the
code. The function that finds them is called sideOfTreePath.
@@ -260,7 +260,7 @@ does by definition not change. Also, if the constrained point is
redefined so that it is no longer constrained to any curve, this is a
major problem, because it would tqinvalidate the locus. Another point
is that in practice, the locus depends on more objects than its
-tqparents alone. This is not a good thing, because it makes it
+parents alone. This is not a good thing, because it makes it
impossible to optimise drawing of the objects, using the information
about which objects depend on which others, because this information
is invalid.
diff --git a/kig/TODO b/kig/TODO
index a6f97fe3..717d5124 100644
--- a/kig/TODO
+++ b/kig/TODO
@@ -102,8 +102,8 @@
- extend ObjectFactory::sensiblePointCalcer to also construct
intersection points of stuff... (pino: done for lines)
-- when moving an object that wants to move its tqparents, try to check if
- it is itself not an indirect child of one of the tqparents it is
+- when moving an object that wants to move its parents, try to check if
+ it is itself not an indirect child of one of the parents it is
trying to move, and forbid the move in that case, as it will lead
to chaotic behaviour. I am not sure if this is really well
possible, but I have to look at it.
diff --git a/kig/examples/figure_angle.fgeo b/kig/examples/figure_angle.fgeo
index 47076564..6265e7e4 100644
--- a/kig/examples/figure_angle.fgeo
+++ b/kig/examples/figure_angle.fgeo
@@ -1,27 +1,27 @@
-
+
-5.833333
2.950000
-
+
-4.666666
-0.783334
-
+
2.333334
-0.216667
-
+
-
+
-
+
diff --git a/kig/examples/figure_manyobjects.fgeo b/kig/examples/figure_manyobjects.fgeo
index c89c976f..1e50da51 100644
--- a/kig/examples/figure_manyobjects.fgeo
+++ b/kig/examples/figure_manyobjects.fgeo
@@ -1,69 +1,69 @@
-
+
-6.700000
2.250000
-
+
0.266667
2.083333
-
+
-0.800000
-2.516667
-
+
-2.766667
1.883333
-
+
-
+
-
+
-2.833333
-0.983334
-
+
1.500000
1.883333
-
+
-0.566667
3.983333
-
+
-
+
-
+
-5.533333
-0.383333
-
+
-2.800000
1.883333
-
+
3.166667
-0.683333
-
+
-
+
diff --git a/kig/examples/session_alotofthings.fgeo b/kig/examples/session_alotofthings.fgeo
index dc8bb729..b47c31d9 100644
--- a/kig/examples/session_alotofthings.fgeo
+++ b/kig/examples/session_alotofthings.fgeo
@@ -1,64 +1,64 @@
-
+
0.766667
2.450000
-
+
-3.300000
2.650000
-
+
-7.900000
-2.583333
-
+
-7.800000
0.116667
-
+
-4.533333
1.216667
-
+
-8.566667
3.116667
-
+
-7.066667
1.783334
-
+
-
+
-
+
-
+
-1.066667
-0.416667
-
+
-
+
-
+
-
+
@@ -86,75 +86,75 @@ Figure 3 tqcontains:
- a moved circle;
-
+
-5.200000
0.216667
-
+
1.200000
3.116667
-
+
-7.666667
1.650000
-
+
-
+
-
+
-
+
-6.200000
-1.483334
-
+
-
+
-
+
-
+
-6.433334
2.050000
-
+
-1.400000
2.583333
-
+
-1.300000
-0.350000
-
+
-3.433333
-0.883333
-
+
-6.433334
2.050000
-
+
-
+
diff --git a/kig/filters/cabri-filter.cc b/kig/filters/cabri-filter.cc
index 55ecf939..2348af86 100644
--- a/kig/filters/cabri-filter.cc
+++ b/kig/filters/cabri-filter.cc
@@ -56,7 +56,7 @@
*
* Nr: Simple sequential numbering of the objects in a file.
* Type: seen so far: Pt, Axes, Line, Cir
- * NumberOfParents: The number of tqparents that will be specified in
+ * NumberOfParents: The number of parents that will be specified in
* Parents
* Color:
* R -> red
@@ -96,7 +96,7 @@
* Visible:
* V means visible, I means invisible
* Fixed:
- * St means fix this object ( if you move one of its tqparents, it
+ * St means fix this object ( if you move one of its parents, it
* won't move ), nSt ( the default ) means don't fix this object.
* Parents:
* The numbers of the objects this object depends on
@@ -118,7 +118,7 @@ struct CabriObject
int specialAppearanceSwitch;
bool visible;
bool fixed;
- std::vector tqparents;
+ std::vector parents;
std::vector data;
};
@@ -246,14 +246,14 @@ bool KigFilterCabri::readObject( TQFile& f, CabriObject& myobj )
KIG_FILTER_PARSE_ERROR;
tmp = thirdlinere.cap( 2 );
- TQStringList tqparentsids = TQStringList::split( ' ', tmp );
- for ( TQStringList::iterator i = tqparentsids.begin();
- i != tqparentsids.end(); ++i )
+ TQStringList parentsids = TQStringList::split( ' ', tmp );
+ for ( TQStringList::iterator i = parentsids.begin();
+ i != parentsids.end(); ++i )
{
- myobj.tqparents.push_back( ( *i ).toInt( &ok ) );
+ myobj.parents.push_back( ( *i ).toInt( &ok ) );
if ( ! ok ) KIG_FILTER_PARSE_ERROR;
}
- if ( myobj.tqparents.size() != myobj.numberOfParents )
+ if ( myobj.parents.size() != myobj.numberOfParents )
KIG_FILTER_PARSE_ERROR;
tmp = thirdlinere.cap( 4 );
@@ -277,8 +277,8 @@ bool KigFilterCabri::readObject( TQFile& f, CabriObject& myobj )
// << "specialAppearanceSwitch = " << myobj.specialAppearanceSwitch << endl
// << "visible = " << visible << endl
// << "fixed = " << myobj.fixed << endl
-// << "tqparents =" << endl;
-// for ( std::vector::iterator i = myobj.tqparents.begin(); i != myobj.tqparents.end(); ++i )
+// << "parents =" << endl;
+// for ( std::vector::iterator i = myobj.parents.begin(); i != myobj.parents.end(); ++i )
// kdDebug() << " " << *i << endl;
// kdDebug() << "vals = " << endl;
// for ( std::vector::iterator i = myobj.data.begin(); i != myobj.data.end(); ++i )
@@ -352,8 +352,8 @@ KigDocument* KigFilterCabri::load( const TQString& file )
int ps = 0;
args.clear();
- for ( std::vector::iterator i = obj.tqparents.begin();
- i != obj.tqparents.end(); ++i )
+ for ( std::vector::iterator i = obj.parents.begin();
+ i != obj.parents.end(); ++i )
args.push_back( calcers[*i-3] );
// two fake objects at the start ( origin and axes.. )
diff --git a/kig/filters/drgeo-filter-chooserbase.ui b/kig/filters/drgeo-filter-chooserbase.ui
index b58e3dc1..1a9589b2 100644
--- a/kig/filters/drgeo-filter-chooserbase.ui
+++ b/kig/filters/drgeo-filter-chooserbase.ui
@@ -131,7 +131,7 @@ Please select which to import:
-
+
klistbox.h
kpushbutton.h
diff --git a/kig/filters/drgeo-filter.cc b/kig/filters/drgeo-filter.cc
index 3f213146..856d995c 100644
--- a/kig/filters/drgeo-filter.cc
+++ b/kig/filters/drgeo-filter.cc
@@ -62,7 +62,7 @@
struct DrGeoHierarchyElement
{
TQString id;
- std::vector tqparents;
+ std::vector parents;
};
KigFilterDrgeo::KigFilterDrgeo()
@@ -202,7 +202,7 @@ KigDocument* KigFilterDrgeo::importFigure( TQDomNode f, const TQString& file, co
TQDomElement ce = c.toElement();
if ( ce.isNull() ) continue;
else if ( ce.tagName() == "tqparent" )
- elem.tqparents.push_back( ce.attribute( "ref" ) );
+ elem.parents.push_back( ce.attribute( "ref" ) );
}
TQString curid = domelem.attribute( "id" );
elem.id = !curid.isNull() ? curid : TQString::number( withoutid++ ) ;
@@ -216,9 +216,9 @@ KigDocument* KigFilterDrgeo::importFigure( TQDomNode f, const TQString& file, co
for ( uint i = 0; i < elems.size(); ++i )
{
x = "";
- for ( uint j = 0; j < elems[i].tqparents.size(); ++j )
+ for ( uint j = 0; j < elems[i].parents.size(); ++j )
{
- x += elems[i].tqparents[j] + "_";
+ x += elems[i].parents[j] + "_";
}
kdDebug() << " --> " << i << " - " << elems[i].id << " - " << x << endl;
}
@@ -241,25 +241,25 @@ KigDocument* KigFilterDrgeo::importFigure( TQDomNode f, const TQString& file, co
kdDebug() << "+++ id: " << curid << endl;
#endif
const DrGeoHierarchyElement& el = elems[curid];
- std::vector tqparents;
- for ( uint j = 0; j < el.tqparents.size(); ++j )
+ std::vector parents;
+ for ( uint j = 0; j < el.parents.size(); ++j )
{
- int tqparentid = convertDrgeoIndex( elems, el.tqparents[j] );
- if ( tqparentid == -1 )
+ int parentid = convertDrgeoIndex( elems, el.parents[j] );
+ if ( parentid == -1 )
KIG_FILTER_PARSE_ERROR;
- tqparents.push_back( holders[tqparentid-nignored]->calcer() );
+ parents.push_back( holders[parentid-nignored]->calcer() );
};
TQDomElement domelem = a.toElement();
#ifdef DRGEO_DEBUG
- if ( tqparents.size() > 0 )
- for ( uint j = 0; j < tqparents.size(); ++j )
+ if ( parents.size() > 0 )
+ for ( uint j = 0; j < parents.size(); ++j )
{
- kdDebug() << "+++++++++ tqparent[" << j << "]: " << tqparents[j] << " - "
- << tqparents[j]->imp()->type()->internalName() << endl;
+ kdDebug() << "+++++++++ tqparent[" << j << "]: " << parents[j] << " - "
+ << parents[j]->imp()->type()->internalName() << endl;
}
else
- kdDebug() << "+++++++++ tqparents: NO" << endl;
+ kdDebug() << "+++++++++ parents: NO" << endl;
kdDebug() << "+++++++++ " << domelem.tagName() << " - " << domelem.attribute("type") << endl;
#endif
@@ -291,15 +291,15 @@ KigDocument* KigFilterDrgeo::importFigure( TQDomNode f, const TQString& file, co
oc = fact->fixedPointCalcer( Coordinate( x, y ) );
}
else if ( domelem.attribute( "type" ) == "Middle_2pts" )
- oc = new ObjectTypeCalcer( MidPointType::instance(), tqparents );
+ oc = new ObjectTypeCalcer( MidPointType::instance(), parents );
else if ( domelem.attribute( "type" ) == "Middle_segment" )
{
- if ( tqparents.size() != 1 ) KIG_FILTER_PARSE_ERROR;
- if ( !tqparents[0]->imp()->inherits( SegmentImp::stype() ) )
+ if ( parents.size() != 1 ) KIG_FILTER_PARSE_ERROR;
+ if ( !parents[0]->imp()->inherits( SegmentImp::stype() ) )
KIG_FILTER_PARSE_ERROR;
- ObjectPropertyCalcer* o1 = fact->propertyObjectCalcer( tqparents[0], "end-point-A" );
+ ObjectPropertyCalcer* o1 = fact->propertyObjectCalcer( parents[0], "end-point-A" );
o1->calc( *ret );
- ObjectPropertyCalcer* o2 = fact->propertyObjectCalcer( tqparents[0], "end-point-B" );
+ ObjectPropertyCalcer* o2 = fact->propertyObjectCalcer( parents[0], "end-point-B" );
o2->calc( *ret );
std::vector args;
args.push_back( o1 );
@@ -312,26 +312,26 @@ KigDocument* KigFilterDrgeo::importFigure( TQDomNode f, const TQString& file, co
double value = values.toDouble( &ok3 );
if ( ! ok3 )
KIG_FILTER_PARSE_ERROR;
- if ( ( tqparents[0]->imp()->inherits( CircleImp::stype() ) ) ||
- ( tqparents[0]->imp()->inherits( SegmentImp::stype() ) ) )
- oc = fact->constrainedPointCalcer( tqparents[0], value );
- else if ( tqparents[0]->imp()->inherits( LineImp::stype() ) )
+ if ( ( parents[0]->imp()->inherits( CircleImp::stype() ) ) ||
+ ( parents[0]->imp()->inherits( SegmentImp::stype() ) ) )
+ oc = fact->constrainedPointCalcer( parents[0], value );
+ else if ( parents[0]->imp()->inherits( LineImp::stype() ) )
{
- const LineData l = static_cast( tqparents[0]->imp() )->data();
+ const LineData l = static_cast( parents[0]->imp() )->data();
const Coordinate p = convertDrgeoLineParam( value, l );
- oc = fact->constrainedPointCalcer( tqparents[0], p, *ret );
+ oc = fact->constrainedPointCalcer( parents[0], p, *ret );
}
- else if ( tqparents[0]->imp()->inherits( RayImp::stype() ) )
+ else if ( parents[0]->imp()->inherits( RayImp::stype() ) )
{
- const LineData l = static_cast( tqparents[0]->imp() )->data();
+ const LineData l = static_cast( parents[0]->imp() )->data();
const Coordinate p = convertDrgeoHalflineParam( value, l );
- oc = fact->constrainedPointCalcer( tqparents[0], p, *ret );
+ oc = fact->constrainedPointCalcer( parents[0], p, *ret );
}
- else if ( tqparents[0]->imp()->inherits( ArcImp::stype() ) )
- oc = fact->constrainedPointCalcer( tqparents[0], 1 - value );
+ else if ( parents[0]->imp()->inherits( ArcImp::stype() ) )
+ oc = fact->constrainedPointCalcer( parents[0], 1 - value );
else
{
-// oc = fact->constrainedPointCalcer( tqparents[0], value );
+// oc = fact->constrainedPointCalcer( parents[0], value );
notSupported( file, i18n( "This Dr. Geo file contains a \"%1 %2\" object, "
"which Kig does not currently support." ).tqarg( domelem.tagName() ).tqarg(
domelem.attribute( "type" ) ) );
@@ -340,9 +340,9 @@ KigDocument* KigFilterDrgeo::importFigure( TQDomNode f, const TQString& file, co
}
else if ( domelem.attribute( "type" ) == "Intersection" )
{
- if ( ( tqparents[0]->imp()->inherits( AbstractLineImp::stype() ) ) &&
- ( tqparents[1]->imp()->inherits( AbstractLineImp::stype() ) ) )
- oc = new ObjectTypeCalcer( LineLineIntersectionType::instance(), tqparents );
+ if ( ( parents[0]->imp()->inherits( AbstractLineImp::stype() ) ) &&
+ ( parents[1]->imp()->inherits( AbstractLineImp::stype() ) ) )
+ oc = new ObjectTypeCalcer( LineLineIntersectionType::instance(), parents );
else
{
bool ok;
@@ -351,21 +351,21 @@ KigDocument* KigFilterDrgeo::importFigure( TQDomNode f, const TQString& file, co
if ( which == 1 ) which = -1;
else if ( which == 0 ) which = 1;
else KIG_FILTER_PARSE_ERROR;
- std::vector args = tqparents;
+ std::vector args = parents;
const ObjectType* type = 0;
args.push_back( new ObjectConstCalcer( new IntImp( which ) ) );
- if ( ( tqparents[0]->imp()->inherits( CircleImp::stype() ) ) &&
- ( tqparents[1]->imp()->inherits( CircleImp::stype() ) ) )
+ if ( ( parents[0]->imp()->inherits( CircleImp::stype() ) ) &&
+ ( parents[1]->imp()->inherits( CircleImp::stype() ) ) )
type = CircleCircleIntersectionType::instance();
- else if ( ( tqparents[0]->imp()->inherits( CircleImp::stype() ) &&
- tqparents[1]->imp()->inherits( AbstractLineImp::stype() ) ) ||
- ( tqparents[1]->imp()->inherits( CircleImp::stype() ) &&
- tqparents[0]->imp()->inherits( AbstractLineImp::stype() ) ) )
+ else if ( ( parents[0]->imp()->inherits( CircleImp::stype() ) &&
+ parents[1]->imp()->inherits( AbstractLineImp::stype() ) ) ||
+ ( parents[1]->imp()->inherits( CircleImp::stype() ) &&
+ parents[0]->imp()->inherits( AbstractLineImp::stype() ) ) )
type = ConicLineIntersectionType::instance();
- else if ( ( tqparents[0]->imp()->inherits( ArcImp::stype() ) &&
- tqparents[1]->imp()->inherits( AbstractLineImp::stype() ) ) ||
- ( tqparents[1]->imp()->inherits( ArcImp::stype() ) &&
- tqparents[0]->imp()->inherits( AbstractLineImp::stype() ) ) )
+ else if ( ( parents[0]->imp()->inherits( ArcImp::stype() ) &&
+ parents[1]->imp()->inherits( AbstractLineImp::stype() ) ) ||
+ ( parents[1]->imp()->inherits( ArcImp::stype() ) &&
+ parents[0]->imp()->inherits( AbstractLineImp::stype() ) ) )
type = ArcLineIntersectionType::instance();
else
{
@@ -377,13 +377,13 @@ KigDocument* KigFilterDrgeo::importFigure( TQDomNode f, const TQString& file, co
}
}
else if ( domelem.attribute( "type" ) == "Reflexion" )
- oc = new ObjectTypeCalcer( LineReflectionType::instance(), tqparents );
+ oc = new ObjectTypeCalcer( LineReflectionType::instance(), parents );
else if ( domelem.attribute( "type" ) == "Symmetry" )
- oc = new ObjectTypeCalcer( PointReflectionType::instance(), tqparents );
+ oc = new ObjectTypeCalcer( PointReflectionType::instance(), parents );
else if ( domelem.attribute( "type" ) == "Translation" )
- oc = new ObjectTypeCalcer( TranslatedType::instance(), tqparents );
+ oc = new ObjectTypeCalcer( TranslatedType::instance(), parents );
else if ( domelem.attribute( "type" ) == "Rotation" )
- oc = new ObjectTypeCalcer( RotationType::instance(), tqparents );
+ oc = new ObjectTypeCalcer( RotationType::instance(), parents );
else
{
notSupported( file, i18n( "This Dr. Geo file contains a \"%1 %2\" object, "
@@ -423,7 +423,7 @@ KigDocument* KigFilterDrgeo::importFigure( TQDomNode f, const TQString& file, co
domelem.attribute( "type" ) ) );
return false;
}
- oc = new ObjectTypeCalcer( type, tqparents );
+ oc = new ObjectTypeCalcer( type, parents );
}
else if( domelem.attribute( "type" ) == "3pts" )
{
@@ -436,19 +436,19 @@ KigDocument* KigFilterDrgeo::importFigure( TQDomNode f, const TQString& file, co
domelem.attribute( "type" ) ) );
return false;
}
- oc = new ObjectTypeCalcer( type, tqparents );
+ oc = new ObjectTypeCalcer( type, parents );
}
else if( domelem.attribute( "type" ) == "segment" )
{
if( domelem.tagName() == "circle" )
{
type = CircleBPRType::instance();
- ObjectPropertyCalcer* o = fact->propertyObjectCalcer( tqparents[1], "length" );
+ ObjectPropertyCalcer* o = fact->propertyObjectCalcer( parents[1], "length" );
o->calc( *ret );
- ObjectCalcer* a = tqparents[0];
- tqparents.clear();
- tqparents.push_back( a );
- tqparents.push_back( o );
+ ObjectCalcer* a = parents[0];
+ parents.clear();
+ parents.push_back( a );
+ parents.push_back( o );
}
else
{
@@ -457,13 +457,13 @@ KigDocument* KigFilterDrgeo::importFigure( TQDomNode f, const TQString& file, co
domelem.attribute( "type" ) ) );
return false;
}
- oc = new ObjectTypeCalcer( type, tqparents );
+ oc = new ObjectTypeCalcer( type, parents );
}
else if( domelem.attribute( "type" ) == "npts" )
{
if( domelem.tagName() == "polygon" )
{
- if ( tqparents.size() < 3 ) KIG_FILTER_PARSE_ERROR;
+ if ( parents.size() < 3 ) KIG_FILTER_PARSE_ERROR;
type = PolygonBNPType::instance();
}
else
@@ -473,20 +473,20 @@ KigDocument* KigFilterDrgeo::importFigure( TQDomNode f, const TQString& file, co
domelem.attribute( "type" ) ) );
return false;
}
- oc = new ObjectTypeCalcer( type, tqparents );
+ oc = new ObjectTypeCalcer( type, parents );
}
else if ( domelem.attribute( "type" ) == "perpendicular" )
- oc = new ObjectTypeCalcer( LinePerpendLPType::instance(), tqparents );
+ oc = new ObjectTypeCalcer( LinePerpendLPType::instance(), parents );
else if ( domelem.attribute( "type" ) == "parallel" )
- oc = new ObjectTypeCalcer( LineParallelLPType::instance(), tqparents );
+ oc = new ObjectTypeCalcer( LineParallelLPType::instance(), parents );
else if ( domelem.attribute( "type" ) == "Reflexion" )
- oc = new ObjectTypeCalcer( LineReflectionType::instance(), tqparents );
+ oc = new ObjectTypeCalcer( LineReflectionType::instance(), parents );
else if ( domelem.attribute( "type" ) == "Symmetry" )
- oc = new ObjectTypeCalcer( PointReflectionType::instance(), tqparents );
+ oc = new ObjectTypeCalcer( PointReflectionType::instance(), parents );
else if ( domelem.attribute( "type" ) == "Translation" )
- oc = new ObjectTypeCalcer( TranslatedType::instance(), tqparents );
+ oc = new ObjectTypeCalcer( TranslatedType::instance(), parents );
else if ( domelem.attribute( "type" ) == "Rotation" )
- oc = new ObjectTypeCalcer( RotationType::instance(), tqparents );
+ oc = new ObjectTypeCalcer( RotationType::instance(), parents );
else
{
notSupported( file, i18n( "This Dr. Geo file contains a \"%1 %2\" object, "
@@ -534,71 +534,71 @@ KigDocument* KigFilterDrgeo::importFigure( TQDomNode f, const TQString& file, co
}
else if ( domelem.attribute( "type" ) == "pt_abscissa" )
{
- if ( tqparents.size() != 1 ) KIG_FILTER_PARSE_ERROR;
- oc = filtersConstructTextObject( m, tqparents[0], "coordinate-x", *ret, false );
+ if ( parents.size() != 1 ) KIG_FILTER_PARSE_ERROR;
+ oc = filtersConstructTextObject( m, parents[0], "coordinate-x", *ret, false );
}
else if ( domelem.attribute( "type" ) == "pt_ordinate" )
{
- if ( tqparents.size() != 1 ) KIG_FILTER_PARSE_ERROR;
- oc = filtersConstructTextObject( m, tqparents[0], "coordinate-y", *ret, false );
+ if ( parents.size() != 1 ) KIG_FILTER_PARSE_ERROR;
+ oc = filtersConstructTextObject( m, parents[0], "coordinate-y", *ret, false );
}
else if ( domelem.attribute( "type" ) == "segment_length" )
{
- if ( tqparents.size() != 1 ) KIG_FILTER_PARSE_ERROR;
- oc = filtersConstructTextObject( m, tqparents[0], "length", *ret, false );
+ if ( parents.size() != 1 ) KIG_FILTER_PARSE_ERROR;
+ oc = filtersConstructTextObject( m, parents[0], "length", *ret, false );
}
else if ( domelem.attribute( "type" ) == "circle_perimeter" )
{
- if ( tqparents.size() != 1 ) KIG_FILTER_PARSE_ERROR;
- oc = filtersConstructTextObject( m, tqparents[0], "circumference", *ret, false );
+ if ( parents.size() != 1 ) KIG_FILTER_PARSE_ERROR;
+ oc = filtersConstructTextObject( m, parents[0], "circumference", *ret, false );
}
else if ( domelem.attribute( "type" ) == "arc_length" )
{
- if ( tqparents.size() != 1 ) KIG_FILTER_PARSE_ERROR;
- oc = filtersConstructTextObject( m, tqparents[0], "arc-length", *ret, false );
+ if ( parents.size() != 1 ) KIG_FILTER_PARSE_ERROR;
+ oc = filtersConstructTextObject( m, parents[0], "arc-length", *ret, false );
}
else if ( domelem.attribute( "type" ) == "distance_2pts" )
{
- if ( tqparents.size() != 2 ) KIG_FILTER_PARSE_ERROR;
- ObjectTypeCalcer* so = new ObjectTypeCalcer( SegmentABType::instance(), tqparents );
+ if ( parents.size() != 2 ) KIG_FILTER_PARSE_ERROR;
+ ObjectTypeCalcer* so = new ObjectTypeCalcer( SegmentABType::instance(), parents );
so->calc( *ret );
oc = filtersConstructTextObject( m, so, "length", *ret, false );
}
else if ( domelem.attribute( "type" ) == "vector_norm" )
{
- if ( tqparents.size() != 1 ) KIG_FILTER_PARSE_ERROR;
- oc = filtersConstructTextObject( m, tqparents[0], "length", *ret, false );
+ if ( parents.size() != 1 ) KIG_FILTER_PARSE_ERROR;
+ oc = filtersConstructTextObject( m, parents[0], "length", *ret, false );
}
else if ( domelem.attribute( "type" ) == "vector_abscissa" )
{
- if ( tqparents.size() != 1 ) KIG_FILTER_PARSE_ERROR;
- oc = filtersConstructTextObject( m, tqparents[0], "length-x", *ret, false );
+ if ( parents.size() != 1 ) KIG_FILTER_PARSE_ERROR;
+ oc = filtersConstructTextObject( m, parents[0], "length-x", *ret, false );
}
else if ( domelem.attribute( "type" ) == "vector_ordinate" )
{
- if ( tqparents.size() != 1 ) KIG_FILTER_PARSE_ERROR;
- oc = filtersConstructTextObject( m, tqparents[0], "length-y", *ret, false );
+ if ( parents.size() != 1 ) KIG_FILTER_PARSE_ERROR;
+ oc = filtersConstructTextObject( m, parents[0], "length-y", *ret, false );
}
else if ( domelem.attribute( "type" ) == "slope" )
{
- if ( tqparents.size() != 1 ) KIG_FILTER_PARSE_ERROR;
- oc = filtersConstructTextObject( m, tqparents[0], "slope", *ret, false );
+ if ( parents.size() != 1 ) KIG_FILTER_PARSE_ERROR;
+ oc = filtersConstructTextObject( m, parents[0], "slope", *ret, false );
}
else if ( domelem.attribute( "type" ) == "distance_pt_line" )
{
- if ( tqparents.size() != 2 ) KIG_FILTER_PARSE_ERROR;
+ if ( parents.size() != 2 ) KIG_FILTER_PARSE_ERROR;
std::vector args;
- args.push_back( tqparents[1] );
- args.push_back( tqparents[0] );
+ args.push_back( parents[1] );
+ args.push_back( parents[0] );
ObjectTypeCalcer* po = new ObjectTypeCalcer( LinePerpendLPType::instance(), args );
po->calc( *ret );
args.clear();
- args.push_back( tqparents[1] );
+ args.push_back( parents[1] );
args.push_back( po );
ObjectTypeCalcer* io = new ObjectTypeCalcer( LineLineIntersectionType::instance(), args );
io->calc( *ret );
args.clear();
- args.push_back( tqparents[0] );
+ args.push_back( parents[0] );
args.push_back( io );
ObjectTypeCalcer* so = new ObjectTypeCalcer( SegmentABType::instance(), args );
so->calc( *ret );
@@ -607,13 +607,13 @@ KigDocument* KigFilterDrgeo::importFigure( TQDomNode f, const TQString& file, co
// types of 'equation'
else if ( domelem.attribute( "type" ) == "line" )
{
- if ( tqparents.size() != 1 ) KIG_FILTER_PARSE_ERROR;
- oc = filtersConstructTextObject( m, tqparents[0], "equation", *ret, false );
+ if ( parents.size() != 1 ) KIG_FILTER_PARSE_ERROR;
+ oc = filtersConstructTextObject( m, parents[0], "equation", *ret, false );
}
else if ( domelem.attribute( "type" ) == "circle" )
{
- if ( tqparents.size() != 1 ) KIG_FILTER_PARSE_ERROR;
- oc = filtersConstructTextObject( m, tqparents[0], "simply-cartesian-equation", *ret, false );
+ if ( parents.size() != 1 ) KIG_FILTER_PARSE_ERROR;
+ oc = filtersConstructTextObject( m, parents[0], "simply-cartesian-equation", *ret, false );
}
else
{
@@ -630,8 +630,8 @@ KigDocument* KigFilterDrgeo::importFigure( TQDomNode f, const TQString& file, co
{
if ( domelem.attribute( "type" ) == "3pts" )
{
- if ( tqparents.size() != 3 ) KIG_FILTER_PARSE_ERROR;
- oc = new ObjectTypeCalcer( HalfAngleType::instance(), tqparents );
+ if ( parents.size() != 3 ) KIG_FILTER_PARSE_ERROR;
+ oc = new ObjectTypeCalcer( HalfAngleType::instance(), parents );
}
else
{
@@ -669,7 +669,7 @@ KigDocument* KigFilterDrgeo::importFigure( TQDomNode f, const TQString& file, co
// since Kig doesn't support Guile scripts, it will write script's text
// in a label, so the user can freely see the code and make whatever
// he/she wants
- // possible idea: construct a new script object with the tqparents of Guile
+ // possible idea: construct a new script object with the parents of Guile
// one and the Guile code inserted commented... depends on a better
// handling of arguments in scripts?
if ( domelem.attribute( "type" ) == "nitems" )
@@ -685,7 +685,7 @@ KigDocument* KigFilterDrgeo::importFigure( TQDomNode f, const TQString& file, co
else if ( domelem.tagName() == "locus" )
{
if ( domelem.attribute( "type" ) == "None" )
- oc = fact->locusCalcer( tqparents[0], tqparents[1] );
+ oc = fact->locusCalcer( parents[0], parents[1] );
else
{
notSupported( file, i18n( "This Dr. Geo file contains a \"%1 %2\" object, "
@@ -747,8 +747,8 @@ KigDocument* KigFilterDrgeo::importFigure( TQDomNode f, const TQString& file, co
TQString ps = domelem.attribute( "style" );
int pointstyle = ObjectDrawer::pointStyleFromString( ps );
// show this object?
- bool show = ( ( domelem.attribute( "tqmasked" ) != "True" ) &&
- ( domelem.attribute( "tqmasked" ) != "Alway" ) );
+ bool show = ( ( domelem.attribute( "masked" ) != "True" ) &&
+ ( domelem.attribute( "masked" ) != "Alway" ) );
// costructing the ObjectDrawer*
ObjectDrawer* d = new ObjectDrawer( co, w, show, s, pointstyle );
// reading object name
@@ -779,7 +779,7 @@ KigDocument* KigFilterDrgeo::importFigure( TQDomNode f, const TQString& file, co
else if ( domelem.tagName() == "angle" )
{
oc2 = filtersConstructTextObject(
- static_cast( holders[curid-1-nignored]->calcer()->tqparents()[1]->imp() )->coordinate(),
+ static_cast( holders[curid-1-nignored]->calcer()->parents()[1]->imp() )->coordinate(),
holders[curid-1-nignored]->calcer(), "angle-degrees", *ret, false );
}
diff --git a/kig/filters/imageexporteroptionsbase.ui b/kig/filters/imageexporteroptionsbase.ui
index 5b2fbb67..2a9156bf 100644
--- a/kig/filters/imageexporteroptionsbase.ui
+++ b/kig/filters/imageexporteroptionsbase.ui
@@ -144,7 +144,7 @@
-
+
knuminput.h
knuminput.h
diff --git a/kig/filters/kgeo-filter.cc b/kig/filters/kgeo-filter.cc
index 379af11d..2405e46b 100644
--- a/kig/filters/kgeo-filter.cc
+++ b/kig/filters/kgeo-filter.cc
@@ -74,7 +74,7 @@ void KigFilterKGeo::loadMetrics(KSimpleConfig* c )
struct KGeoHierarchyElement
{
int id;
- std::vector tqparents;
+ std::vector parents;
};
static void visitElem( std::vector& ret,
@@ -84,8 +84,8 @@ static void visitElem( std::vector& ret,
{
if ( !seen[i] )
{
- for ( uint j = 0; j < elems[i].tqparents.size(); ++j )
- visitElem( ret, elems, seen, elems[i].tqparents[j] );
+ for ( uint j = 0; j < elems[i].parents.size(); ++j )
+ visitElem( ret, elems, seen, elems[i].parents[j] );
ret.push_back( elems[i] );
seen[i] = true;
};
@@ -113,7 +113,7 @@ KigDocument* KigFilterKGeo::loadObjects( const TQString& file, KSimpleConfig* c
// first we determine the tqparent relationships, and sort the
// elements in an order that we can be sure all of an object's
- // tqparents will have been handled before it is handled itself..
+ // parents will have been handled before it is handled itself..
// ( aka topological sort of the tqparent relations graph..
std::vector elems;
elems.reserve( number );
@@ -125,15 +125,15 @@ KigDocument* KigFilterKGeo::loadObjects( const TQString& file, KSimpleConfig* c
group.setNum( i + 1 );
group.prepend( "Object " );
c->setGroup( group );
- TQStrList tqparents;
- c->readListEntry( "Parents", tqparents );
+ TQStrList parents;
+ c->readListEntry( "Parents", parents );
elems.push_back( elem );
- for ( const char* tqparent = tqparents.first(); tqparent; tqparent = tqparents.next() )
+ for ( const char* tqparent = parents.first(); tqparent; tqparent = parents.next() )
{
- int tqparentIndex = TQString::tqfromLatin1( tqparent ).toInt( &ok );
+ int parentIndex = TQString::tqfromLatin1( tqparent ).toInt( &ok );
if ( ! ok ) KIG_FILTER_PARSE_ERROR;
- if ( tqparentIndex != 0 )
- elems[i].tqparents.push_back( tqparentIndex - 1 );
+ if ( parentIndex != 0 )
+ elems[i].parents.push_back( parentIndex - 1 );
};
};
@@ -153,11 +153,11 @@ KigDocument* KigFilterKGeo::loadObjects( const TQString& file, KSimpleConfig* c
c->setGroup( group );
int objID = c->readNumEntry( "Geo" );
- std::vector tqparents;
- for ( uint j = 0; j < e.tqparents.size(); ++j )
+ std::vector parents;
+ for ( uint j = 0; j < e.parents.size(); ++j )
{
- int tqparentid = e.tqparents[j];
- tqparents.push_back( os[tqparentid]->calcer() );
+ int parentid = e.parents[j];
+ parents.push_back( os[parentid]->calcer() );
};
ObjectCalcer* o = 0;
@@ -173,77 +173,77 @@ KigDocument* KigFilterKGeo::loadObjects( const TQString& file, KSimpleConfig* c
double y = strY.toDouble(&ok);
if (!ok) KIG_FILTER_PARSE_ERROR;
Coordinate m( x, y );
- uint ntqparents = tqparents.size();
- if ( ntqparents == 0 )
+ uint nparents = parents.size();
+ if ( nparents == 0 )
o = factory->fixedPointCalcer( m );
- else if ( ntqparents == 1 )
- o = factory->constrainedPointCalcer( tqparents[0], m, *ret );
+ else if ( nparents == 1 )
+ o = factory->constrainedPointCalcer( parents[0], m, *ret );
else
KIG_FILTER_PARSE_ERROR;
break;
}
case ID_segment:
{
- o = new ObjectTypeCalcer( SegmentABType::instance(), tqparents );
+ o = new ObjectTypeCalcer( SegmentABType::instance(), parents );
break;
}
case ID_circle:
{
- o = new ObjectTypeCalcer( CircleBCPType::instance(), tqparents );
+ o = new ObjectTypeCalcer( CircleBCPType::instance(), parents );
break;
}
case ID_line:
{
- o = new ObjectTypeCalcer( LineABType::instance(), tqparents );
+ o = new ObjectTypeCalcer( LineABType::instance(), parents );
break;
}
case ID_bisection:
{
// if this is the bisection of two points, first build a segment
// between them..
- if ( tqparents.size() == 2 )
+ if ( parents.size() == 2 )
{
- ObjectTypeCalcer* seg = new ObjectTypeCalcer( SegmentABType::instance(), tqparents );
- tqparents.clear();
- tqparents.push_back( seg );
+ ObjectTypeCalcer* seg = new ObjectTypeCalcer( SegmentABType::instance(), parents );
+ parents.clear();
+ parents.push_back( seg );
}
- if ( tqparents.size() != 1 ) KIG_FILTER_PARSE_ERROR;
- o = factory->propertyObjectCalcer( tqparents[0], "mid-point" );
+ if ( parents.size() != 1 ) KIG_FILTER_PARSE_ERROR;
+ o = factory->propertyObjectCalcer( parents[0], "mid-point" );
break;
};
case ID_perpendicular:
{
- o = new ObjectTypeCalcer( LinePerpendLPType::instance(), tqparents );
+ o = new ObjectTypeCalcer( LinePerpendLPType::instance(), parents );
break;
}
case ID_parallel:
{
- o = new ObjectTypeCalcer( LineParallelLPType::instance(), tqparents );
+ o = new ObjectTypeCalcer( LineParallelLPType::instance(), parents );
break;
}
case ID_vector:
{
- o = new ObjectTypeCalcer( VectorType::instance(), tqparents );
+ o = new ObjectTypeCalcer( VectorType::instance(), parents );
break;
}
case ID_ray:
{
- o = new ObjectTypeCalcer( RayABType::instance(), tqparents );
+ o = new ObjectTypeCalcer( RayABType::instance(), parents );
break;
}
case ID_move:
{
- o = new ObjectTypeCalcer( TranslatedType::instance(), tqparents );
+ o = new ObjectTypeCalcer( TranslatedType::instance(), parents );
break;
}
case ID_mirrorPoint:
{
- o = new ObjectTypeCalcer( PointReflectionType::instance(), tqparents );
+ o = new ObjectTypeCalcer( PointReflectionType::instance(), parents );
break;
}
case ID_pointOfConc:
{
- o = new ObjectTypeCalcer( LineLineIntersectionType::instance(), tqparents );
+ o = new ObjectTypeCalcer( LineLineIntersectionType::instance(), parents );
break;
}
case ID_text:
@@ -264,79 +264,79 @@ KigDocument* KigFilterKGeo::loadObjects( const TQString& file, KSimpleConfig* c
case ID_fixedCircle:
{
double r = c->readDoubleNumEntry( "Radius" );
- tqparents.push_back( new ObjectConstCalcer( new DoubleImp( r ) ) );
- o = new ObjectTypeCalcer( CircleBPRType::instance(), tqparents );
+ parents.push_back( new ObjectConstCalcer( new DoubleImp( r ) ) );
+ o = new ObjectTypeCalcer( CircleBPRType::instance(), parents );
break;
}
case ID_angle:
{
- if ( tqparents.size() == 3 )
+ if ( parents.size() == 3 )
{
- ObjectTypeCalcer* ao = new ObjectTypeCalcer( AngleType::instance(), tqparents );
+ ObjectTypeCalcer* ao = new ObjectTypeCalcer( AngleType::instance(), parents );
ao->calc( *ret );
- tqparents.clear();
- tqparents.push_back( ao );
+ parents.clear();
+ parents.push_back( ao );
};
- if ( tqparents.size() != 1 ) KIG_FILTER_PARSE_ERROR;
- ObjectCalcer* angle = tqparents[0];
- tqparents.clear();
+ if ( parents.size() != 1 ) KIG_FILTER_PARSE_ERROR;
+ ObjectCalcer* angle = parents[0];
+ parents.clear();
const Coordinate c =
- static_cast( angle->tqparents()[1]->imp() )->coordinate();
+ static_cast( angle->parents()[1]->imp() )->coordinate();
o = filtersConstructTextObject( c, angle, "angle-degrees", *ret, true );
break;
}
case ID_distance:
{
- if ( tqparents.size() != 2 ) KIG_FILTER_PARSE_ERROR;
- ObjectTypeCalcer* segment = new ObjectTypeCalcer( SegmentABType::instance(), tqparents );
+ if ( parents.size() != 2 ) KIG_FILTER_PARSE_ERROR;
+ ObjectTypeCalcer* segment = new ObjectTypeCalcer( SegmentABType::instance(), parents );
segment->calc( *ret );
- Coordinate m = ( static_cast( tqparents[0]->imp() )->coordinate() +
- static_cast( tqparents[1]->imp() )->coordinate() ) / 2;
+ Coordinate m = ( static_cast( parents[0]->imp() )->coordinate() +
+ static_cast( parents[1]->imp() )->coordinate() ) / 2;
o = filtersConstructTextObject( m, segment, "length", *ret, true );
break;
}
case ID_arc:
{
- o = new ObjectTypeCalcer( AngleType::instance(), tqparents );
+ o = new ObjectTypeCalcer( AngleType::instance(), parents );
break;
}
case ID_area:
{
- if ( tqparents.size() != 1 ) KIG_FILTER_PARSE_ERROR;
- const CircleImp* circle = static_cast( tqparents[0]->imp() );
+ if ( parents.size() != 1 ) KIG_FILTER_PARSE_ERROR;
+ const CircleImp* circle = static_cast( parents[0]->imp() );
const Coordinate c = circle->center() + Coordinate( circle->radius(), 0 );
- o = filtersConstructTextObject( c, tqparents[0], "surface", *ret, true );
+ o = filtersConstructTextObject( c, parents[0], "surface", *ret, true );
break;
}
case ID_slope:
{
- // if tqparents contains a segment, line, vector or whatever, we
- // take its tqparents cause we want points..
- if ( tqparents.size() == 1 ) tqparents = tqparents[0]->tqparents();
- if ( tqparents.size() != 2 ) KIG_FILTER_PARSE_ERROR;
+ // if parents contains a segment, line, vector or whatever, we
+ // take its parents cause we want points..
+ if ( parents.size() == 1 ) parents = parents[0]->parents();
+ if ( parents.size() != 2 ) KIG_FILTER_PARSE_ERROR;
const Coordinate c = (
- static_cast( tqparents[0]->imp() )->coordinate() +
- static_cast( tqparents[1]->imp() )->coordinate() ) / 2;
- ObjectTypeCalcer* line = new ObjectTypeCalcer( LineABType::instance(), tqparents );
+ static_cast( parents[0]->imp() )->coordinate() +
+ static_cast( parents[1]->imp() )->coordinate() ) / 2;
+ ObjectTypeCalcer* line = new ObjectTypeCalcer( LineABType::instance(), parents );
line->calc( *ret );
o = filtersConstructTextObject( c, line, "slope", *ret, true );
break;
}
case ID_circumference:
{
- if ( tqparents.size() != 1 ) KIG_FILTER_PARSE_ERROR;
- const CircleImp* c = static_cast( tqparents[0]->imp() );
+ if ( parents.size() != 1 ) KIG_FILTER_PARSE_ERROR;
+ const CircleImp* c = static_cast( parents[0]->imp() );
const Coordinate m = c->center() + Coordinate( c->radius(), 0 );
- o = filtersConstructTextObject( m, tqparents[0], "circumference", *ret, true );
+ o = filtersConstructTextObject( m, parents[0], "circumference", *ret, true );
break;
}
case ID_rotation:
{
// in kig, the rotated object should be last..
- ObjectCalcer* t = tqparents[2];
- tqparents[2] = tqparents[0];
- tqparents[0] = t;
- o = new ObjectTypeCalcer( RotationType::instance(), tqparents );
+ ObjectCalcer* t = parents[2];
+ parents[2] = parents[0];
+ parents[0] = t;
+ o = new ObjectTypeCalcer( RotationType::instance(), parents );
break;
}
default:
diff --git a/kig/filters/kseg-filter.cc b/kig/filters/kseg-filter.cc
index 6f784759..27edc762 100644
--- a/kig/filters/kseg-filter.cc
+++ b/kig/filters/kseg-filter.cc
@@ -93,50 +93,50 @@ static Coordinate readKSegCoordinate( TQDataStream& stream )
return t + Coordinate( -7, -7 );
}
-static ObjectTypeCalcer* intersectionPoint( const std::vector& tqparents, int which )
+static ObjectTypeCalcer* intersectionPoint( const std::vector& parents, int which )
{
- if ( tqparents.size() != 2 ) return 0;
+ if ( parents.size() != 2 ) return 0;
int nlines = 0;
int nconics = 0;
int narcs = 0;
for ( int i = 0; i < 2; ++i )
{
- if ( tqparents[i]->imp()->inherits( AbstractLineImp::stype() ) ) ++nlines;
- else if ( tqparents[i]->imp()->inherits( ConicImp::stype() ) ) ++nconics;
- else if ( tqparents[i]->imp()->inherits( ArcImp::stype() ) ) ++narcs;
+ if ( parents[i]->imp()->inherits( AbstractLineImp::stype() ) ) ++nlines;
+ else if ( parents[i]->imp()->inherits( ConicImp::stype() ) ) ++nconics;
+ else if ( parents[i]->imp()->inherits( ArcImp::stype() ) ) ++narcs;
else return 0;
};
if ( nlines == 2 )
- return which == -1 ? new ObjectTypeCalcer( LineLineIntersectionType::instance(), tqparents ) : 0;
+ return which == -1 ? new ObjectTypeCalcer( LineLineIntersectionType::instance(), parents ) : 0;
else if ( nlines == 1 && nconics == 1 )
{
- std::vector inttqparents( tqparents );
- inttqparents.push_back( new ObjectConstCalcer( new IntImp( which ) ) );
- return new ObjectTypeCalcer( ConicLineIntersectionType::instance(), inttqparents );
+ std::vector intparents( parents );
+ intparents.push_back( new ObjectConstCalcer( new IntImp( which ) ) );
+ return new ObjectTypeCalcer( ConicLineIntersectionType::instance(), intparents );
}
else if ( nlines == 0 && nconics == 2 )
{
- std::vector rtqparents( tqparents );
- rtqparents.push_back( new ObjectConstCalcer( new IntImp( 1 ) ) );
- rtqparents.push_back( new ObjectConstCalcer( new IntImp( 1 ) ) );
- rtqparents.push_back( new ObjectTypeCalcer( ConicRadicalType::instance(), rtqparents ) );
- std::vector itqparents;
- itqparents.push_back( tqparents[0] );
- itqparents.push_back( rtqparents.back() );
- itqparents.push_back( new ObjectConstCalcer( new IntImp( which ) ) );
- return new ObjectTypeCalcer( ConicLineIntersectionType::instance(), itqparents );
+ std::vector rparents( parents );
+ rparents.push_back( new ObjectConstCalcer( new IntImp( 1 ) ) );
+ rparents.push_back( new ObjectConstCalcer( new IntImp( 1 ) ) );
+ rparents.push_back( new ObjectTypeCalcer( ConicRadicalType::instance(), rparents ) );
+ std::vector iparents;
+ iparents.push_back( parents[0] );
+ iparents.push_back( rparents.back() );
+ iparents.push_back( new ObjectConstCalcer( new IntImp( which ) ) );
+ return new ObjectTypeCalcer( ConicLineIntersectionType::instance(), iparents );
}
else if ( nlines == 1 && narcs == 1 )
{
- std::vector inttqparents( tqparents );
- inttqparents.push_back( new ObjectConstCalcer( new IntImp( which ) ) );
- return new ObjectTypeCalcer( ArcLineIntersectionType::instance(), inttqparents );
+ std::vector intparents( parents );
+ intparents.push_back( new ObjectConstCalcer( new IntImp( which ) ) );
+ return new ObjectTypeCalcer( ArcLineIntersectionType::instance(), intparents );
}
else return 0;
}
ObjectCalcer* KigFilterKSeg::transformObject( const TQString& file, KigDocument& kigdoc,
- std::vector& tqparents,
+ std::vector& parents,
int subtype, bool& ok )
{
ok = true;
@@ -145,34 +145,34 @@ ObjectCalcer* KigFilterKSeg::transformObject( const TQString& file, KigDocument&
{
case G_TRANSLATED:
{
- std::vector vectortqparents( tqparents.begin() + 1, tqparents.end() );
- ObjectTypeCalcer* vector = new ObjectTypeCalcer( VectorType::instance(), vectortqparents );
+ std::vector vectorparents( parents.begin() + 1, parents.end() );
+ ObjectTypeCalcer* vector = new ObjectTypeCalcer( VectorType::instance(), vectorparents );
vector->calc( kigdoc );
std::vector transparents;
- transparents.push_back( tqparents[0] );
+ transparents.push_back( parents[0] );
transparents.push_back( vector );
retobj = new ObjectTypeCalcer( TranslatedType::instance(), transparents );
break;
}
case G_ROTATED:
{
- std::vector angletqparents( tqparents.begin() + 2, tqparents.end() );
- ObjectTypeCalcer* angle = new ObjectTypeCalcer( AngleType::instance(), angletqparents );
+ std::vector angleparents( parents.begin() + 2, parents.end() );
+ ObjectTypeCalcer* angle = new ObjectTypeCalcer( AngleType::instance(), angleparents );
angle->calc( kigdoc );
- std::vector rottqparents;
- rottqparents.push_back( tqparents[0] );
- rottqparents.push_back( tqparents[1] );
- rottqparents.push_back( angle );
- retobj = new ObjectTypeCalcer( RotationType::instance(), rottqparents );
+ std::vector rotparents;
+ rotparents.push_back( parents[0] );
+ rotparents.push_back( parents[1] );
+ rotparents.push_back( angle );
+ retobj = new ObjectTypeCalcer( RotationType::instance(), rotparents );
break;
}
case G_SCALED:
{
- if ( tqparents.size() == 4 )
+ if ( parents.size() == 4 )
{
- retobj = new ObjectTypeCalcer( ScalingOverCenter2Type::instance(), tqparents );
+ retobj = new ObjectTypeCalcer( ScalingOverCenter2Type::instance(), parents );
}
else
{
@@ -187,8 +187,8 @@ ObjectCalcer* KigFilterKSeg::transformObject( const TQString& file, KigDocument&
}
case G_REFLECTED:
{
- std::vector mirtqparents( tqparents.begin(), tqparents.end() );
- retobj = new ObjectTypeCalcer( LineReflectionType::instance(), mirtqparents );
+ std::vector mirparents( parents.begin(), parents.end() );
+ retobj = new ObjectTypeCalcer( LineReflectionType::instance(), mirparents );
break;
}
}
@@ -250,14 +250,14 @@ KigDocument* KigFilterKSeg::load( const TQString& file )
{
short styleid;
stream >> styleid;
- short ntqparents;
- stream >> ntqparents;
- std::vector tqparents( ntqparents, 0 );
- for ( short j = 0; j < ntqparents; ++j )
+ short nparents;
+ stream >> nparents;
+ std::vector parents( nparents, 0 );
+ for ( short j = 0; j < nparents; ++j )
{
int tqparent;
stream >> tqparent;
- tqparents[j] = ret[tqparent]->calcer();
+ parents[j] = ret[tqparent]->calcer();
};
// read the object..
@@ -318,13 +318,13 @@ KigDocument* KigFilterKSeg::load( const TQString& file )
case G_SCALED:
case G_REFLECTED:
{
- o = transformObject( file, *retdoc, tqparents, descendtype, ok );
+ o = transformObject( file, *retdoc, parents, descendtype, ok );
break;
}
case G_FREE_POINT:
{
// fixed point
- if ( ntqparents != 0 ) KIG_FILTER_PARSE_ERROR;
+ if ( nparents != 0 ) KIG_FILTER_PARSE_ERROR;
Coordinate c = readKSegCoordinate( stream );
o = fact->fixedPointCalcer( c );
break;
@@ -334,8 +334,8 @@ KigDocument* KigFilterKSeg::load( const TQString& file )
// constrained point
double p;
stream >> p;
- if ( ntqparents != 1 ) KIG_FILTER_PARSE_ERROR;
- ObjectCalcer* tqparent = tqparents[0];
+ if ( nparents != 1 ) KIG_FILTER_PARSE_ERROR;
+ ObjectCalcer* tqparent = parents[0];
assert( tqparent );
o = fact->constrainedPointCalcer( tqparent, p );
break;
@@ -344,27 +344,27 @@ KigDocument* KigFilterKSeg::load( const TQString& file )
{
// KSeg has somewhat weird intersection objects..
// for all objects G_INTERSECTION_POINT gets the
- // first intersection of its tqparents, G_INTERSECTION2_POINT
+ // first intersection of its parents, G_INTERSECTION2_POINT
// represents the second, if present.
- o = intersectionPoint( tqparents, -1 );
+ o = intersectionPoint( parents, -1 );
if ( ! o ) KIG_FILTER_PARSE_ERROR;
break;
}
case G_INTERSECTION2_POINT:
{
- o = intersectionPoint( tqparents, 1 );
+ o = intersectionPoint( parents, 1 );
if ( ! o ) KIG_FILTER_PARSE_ERROR;
break;
}
case G_MID_POINT:
{
// midpoint of a segment..
- if ( tqparents.size() != 1 ) KIG_FILTER_PARSE_ERROR;
- if ( !tqparents[0]->imp()->inherits( SegmentImp::stype() ) )
+ if ( parents.size() != 1 ) KIG_FILTER_PARSE_ERROR;
+ if ( !parents[0]->imp()->inherits( SegmentImp::stype() ) )
KIG_FILTER_PARSE_ERROR;
- int index = tqparents[0]->imp()->propertiesInternalNames().tqfindIndex( "mid-point" );
+ int index = parents[0]->imp()->propertiesInternalNames().tqfindIndex( "mid-point" );
assert( index != -1 );
- o = new ObjectPropertyCalcer( tqparents[0], index );
+ o = new ObjectPropertyCalcer( parents[0], index );
break;
}
default:
@@ -383,13 +383,13 @@ KigDocument* KigFilterKSeg::load( const TQString& file )
case G_SCALED:
case G_REFLECTED:
{
- o = transformObject( file, *retdoc, tqparents, descendtype, ok );
+ o = transformObject( file, *retdoc, parents, descendtype, ok );
break;
}
case G_ENDPOINTS_SEGMENT:
{
- if ( ntqparents != 2 ) KIG_FILTER_PARSE_ERROR;
- o = new ObjectTypeCalcer( SegmentABType::instance(), tqparents );
+ if ( nparents != 2 ) KIG_FILTER_PARSE_ERROR;
+ o = new ObjectTypeCalcer( SegmentABType::instance(), parents );
break;
}
default:
@@ -406,18 +406,18 @@ KigDocument* KigFilterKSeg::load( const TQString& file )
case G_SCALED:
case G_REFLECTED:
{
- o = transformObject( file, *retdoc, tqparents, descendtype, ok );
+ o = transformObject( file, *retdoc, parents, descendtype, ok );
break;
}
case G_TWOPOINTS_RAY:
{
- if ( ntqparents != 2 ) KIG_FILTER_PARSE_ERROR;
- o = new ObjectTypeCalcer( RayABType::instance(), tqparents );
+ if ( nparents != 2 ) KIG_FILTER_PARSE_ERROR;
+ o = new ObjectTypeCalcer( RayABType::instance(), parents );
break;
}
case G_BISECTOR_RAY:
{
- ObjectTypeCalcer* angle = new ObjectTypeCalcer( HalfAngleType::instance(), tqparents );
+ ObjectTypeCalcer* angle = new ObjectTypeCalcer( HalfAngleType::instance(), parents );
angle->calc( *retdoc );
o = fact->propertyObjectCalcer( angle, "angle-bisector" );
break;
@@ -436,25 +436,25 @@ KigDocument* KigFilterKSeg::load( const TQString& file )
case G_SCALED:
case G_REFLECTED:
{
- o = transformObject( file, *retdoc, tqparents, descendtype, ok );
+ o = transformObject( file, *retdoc, parents, descendtype, ok );
break;
}
case G_TWOPOINTS_LINE:
{
- if ( ntqparents != 2 ) KIG_FILTER_PARSE_ERROR;
- o = new ObjectTypeCalcer( LineABType::instance(), tqparents );
+ if ( nparents != 2 ) KIG_FILTER_PARSE_ERROR;
+ o = new ObjectTypeCalcer( LineABType::instance(), parents );
break;
}
case G_PARALLEL_LINE:
{
- if ( ntqparents != 2 ) KIG_FILTER_PARSE_ERROR;
- o = new ObjectTypeCalcer( LineParallelLPType::instance(), tqparents );
+ if ( nparents != 2 ) KIG_FILTER_PARSE_ERROR;
+ o = new ObjectTypeCalcer( LineParallelLPType::instance(), parents );
break;
}
case G_PERPENDICULAR_LINE:
{
- if ( ntqparents != 2 ) KIG_FILTER_PARSE_ERROR;
- o = new ObjectTypeCalcer( LinePerpendLPType::instance(), tqparents );
+ if ( nparents != 2 ) KIG_FILTER_PARSE_ERROR;
+ o = new ObjectTypeCalcer( LinePerpendLPType::instance(), parents );
break;
}
default:
@@ -471,37 +471,37 @@ KigDocument* KigFilterKSeg::load( const TQString& file )
case G_SCALED:
case G_REFLECTED:
{
- o = transformObject( file, *retdoc, tqparents, descendtype, ok );
+ o = transformObject( file, *retdoc, parents, descendtype, ok );
break;
}
case G_CENTERPOINT_CIRCLE:
{
- if ( ntqparents != 2 ) KIG_FILTER_PARSE_ERROR;
- o = new ObjectTypeCalcer( CircleBCPType::instance(), tqparents );
+ if ( nparents != 2 ) KIG_FILTER_PARSE_ERROR;
+ o = new ObjectTypeCalcer( CircleBCPType::instance(), parents );
break;
}
case G_CENTERRADIUS_CIRCLE:
{
ObjectCalcer* point;
ObjectCalcer* segment;
- if ( tqparents[0]->imp()->inherits( PointImp::stype() ) )
+ if ( parents[0]->imp()->inherits( PointImp::stype() ) )
{
- point = tqparents[0];
- segment = tqparents[1];
+ point = parents[0];
+ segment = parents[1];
}
else
{
- point = tqparents[1];
- segment = tqparents[0];
+ point = parents[1];
+ segment = parents[0];
};
int index = segment->imp()->propertiesInternalNames().tqfindIndex( "length" );
if ( index == -1 ) KIG_FILTER_PARSE_ERROR;
ObjectPropertyCalcer* length = new ObjectPropertyCalcer( segment, index );
length->calc( *retdoc );
- std::vector ctqparents;
- ctqparents.push_back( point );
- ctqparents.push_back( length );
- o = new ObjectTypeCalcer( CircleBPRType::instance(), ctqparents );
+ std::vector cparents;
+ cparents.push_back( point );
+ cparents.push_back( length );
+ o = new ObjectTypeCalcer( CircleBPRType::instance(), cparents );
break;
}
default:
@@ -518,13 +518,13 @@ KigDocument* KigFilterKSeg::load( const TQString& file )
case G_SCALED:
case G_REFLECTED:
{
- o = transformObject( file, *retdoc, tqparents, descendtype, ok );
+ o = transformObject( file, *retdoc, parents, descendtype, ok );
break;
}
case G_THREEPOINTS_ARC:
{
- if ( ntqparents != 3 ) KIG_FILTER_PARSE_ERROR;
- o = new ObjectTypeCalcer( ArcBTPType::instance(), tqparents );
+ if ( nparents != 3 ) KIG_FILTER_PARSE_ERROR;
+ o = new ObjectTypeCalcer( ArcBTPType::instance(), parents );
break;
}
default:
@@ -541,13 +541,13 @@ KigDocument* KigFilterKSeg::load( const TQString& file )
case G_SCALED:
case G_REFLECTED:
{
- o = transformObject( file, *retdoc, tqparents, descendtype, ok );
+ o = transformObject( file, *retdoc, parents, descendtype, ok );
break;
}
default:
{
- if ( ntqparents < 3 ) KIG_FILTER_PARSE_ERROR;
- o = new ObjectTypeCalcer( PolygonBNPType::instance(), tqparents );
+ if ( nparents < 3 ) KIG_FILTER_PARSE_ERROR;
+ o = new ObjectTypeCalcer( PolygonBNPType::instance(), parents );
}
}
// default:
@@ -581,13 +581,13 @@ KigDocument* KigFilterKSeg::load( const TQString& file )
case G_SCALED:
case G_REFLECTED:
{
- o = transformObject( file, *retdoc, tqparents, descendtype, ok );
+ o = transformObject( file, *retdoc, parents, descendtype, ok );
break;
}
case G_OBJECT_LOCUS:
{
- if ( ntqparents != 2 ) KIG_FILTER_PARSE_ERROR;
- o = fact->locusCalcer( tqparents[0], tqparents[1] );
+ if ( nparents != 2 ) KIG_FILTER_PARSE_ERROR;
+ o = fact->locusCalcer( parents[0], parents[1] );
break;
}
default:
diff --git a/kig/filters/kseg-filter.h b/kig/filters/kseg-filter.h
index d8909282..03d03958 100644
--- a/kig/filters/kseg-filter.h
+++ b/kig/filters/kseg-filter.h
@@ -29,7 +29,7 @@ class KigFilterKSeg
~KigFilterKSeg();
ObjectCalcer* transformObject( const TQString& file, KigDocument& kigdoc,
- std::vector& tqparents,
+ std::vector& parents,
int subtype, bool& ok );
public:
diff --git a/kig/filters/latexexporteroptions.ui b/kig/filters/latexexporteroptions.ui
index 2e9354bc..6db39ed9 100644
--- a/kig/filters/latexexporteroptions.ui
+++ b/kig/filters/latexexporteroptions.ui
@@ -63,7 +63,7 @@
-
+
diff --git a/kig/filters/svgexporteroptions.ui b/kig/filters/svgexporteroptions.ui
index feca8ca1..2677650d 100644
--- a/kig/filters/svgexporteroptions.ui
+++ b/kig/filters/svgexporteroptions.ui
@@ -55,7 +55,7 @@
-
+
diff --git a/kig/filters/tests/locus.fgeo b/kig/filters/tests/locus.fgeo
index 4ad79bbd..55fa562f 100644
--- a/kig/filters/tests/locus.fgeo
+++ b/kig/filters/tests/locus.fgeo
@@ -1,2 +1,2 @@
--1.6666663.216667-2.7666670.5500000.0806913.0000003.0166672.866667-0.7500002.6000003.816667
+-1.6666663.216667-2.7666670.5500000.0806913.0000003.0166672.866667-0.7500002.6000003.816667
diff --git a/kig/kig/kig_commands.cpp b/kig/kig/kig_commands.cpp
index d6b79805..bcf26969 100644
--- a/kig/kig/kig_commands.cpp
+++ b/kig/kig/kig_commands.cpp
@@ -274,7 +274,7 @@ class ChangeParentsAndTypeTask::Private
{
public:
ObjectTypeCalcer* o;
- std::vector newtqparents;
+ std::vector newparents;
const ObjectType* newtype;
};
@@ -284,13 +284,13 @@ ChangeParentsAndTypeTask::~ChangeParentsAndTypeTask()
}
ChangeParentsAndTypeTask::ChangeParentsAndTypeTask(
- ObjectTypeCalcer* o, const std::vector& newtqparents,
+ ObjectTypeCalcer* o, const std::vector& newparents,
const ObjectType* newtype )
: KigCommandTask(), d( new Private )
{
d->o = o;
- std::copy( newtqparents.begin(), newtqparents.end(),
- std::back_inserter( d->newtqparents ) );
+ std::copy( newparents.begin(), newparents.end(),
+ std::back_inserter( d->newparents ) );
d->newtype = newtype;
}
@@ -300,17 +300,17 @@ void ChangeParentsAndTypeTask::execute( KigPart& doc )
d->o->setType( d->newtype );
d->newtype = oldtype;
- std::vector oldtqparentso = d->o->tqparents();
- std::vector oldtqparents(
- oldtqparentso.begin(), oldtqparentso.end() );
- std::vector newtqparents;
- for ( std::vector::iterator i = d->newtqparents.begin();
- i != d->newtqparents.end(); ++i )
- newtqparents.push_back( i->get() );
- d->o->setParents( newtqparents );
- d->newtqparents = oldtqparents;
-
- for ( std::vector::iterator i = newtqparents.begin(); i != newtqparents.end(); ++i )
+ std::vector oldparentso = d->o->parents();
+ std::vector oldparents(
+ oldparentso.begin(), oldparentso.end() );
+ std::vector newparents;
+ for ( std::vector::iterator i = d->newparents.begin();
+ i != d->newparents.end(); ++i )
+ newparents.push_back( i->get() );
+ d->o->setParents( newparents );
+ d->newparents = oldparents;
+
+ for ( std::vector::iterator i = newparents.begin(); i != newparents.end(); ++i )
( *i )->calc( doc.document() );
d->o->calc( doc.document() );
std::set alltqchildren = getAllChildren( d->o );
diff --git a/kig/kig/kig_commands.h b/kig/kig/kig_commands.h
index e9df77c1..5bd3ae29 100644
--- a/kig/kig/kig_commands.h
+++ b/kig/kig/kig_commands.h
@@ -59,7 +59,7 @@ public:
static KigCommand* addCommand( KigPart& doc, ObjectHolder* os );
/**
* make sure that when you delete something, you are also deleting
- * its tqparents. This class assumes you've done that.
+ * its parents. This class assumes you've done that.
* \ref KigDocument::delObjects() takes care of this for you.
*/
static KigCommand* removeCommand( KigPart& doc, const std::vector& os );
@@ -124,7 +124,7 @@ protected:
* this class monitors a set of DataObjects for changes and returns an
* appropriate ChangeObjectImpsCommand if necessary..
* E.g. MovingMode wants to move certain objects, so it monitors all
- * the tqparents of the explicitly moving objects:
+ * the parents of the explicitly moving objects:
* \code
* MonitorDataObjects mon( getAllParents( emo ) );
* \endcode
@@ -181,7 +181,7 @@ class ChangeParentsAndTypeTask
class Private;
Private* d;
public:
- ChangeParentsAndTypeTask( ObjectTypeCalcer* o, const std::vector& newtqparents,
+ ChangeParentsAndTypeTask( ObjectTypeCalcer* o, const std::vector& newparents,
const ObjectType* newtype );
~ChangeParentsAndTypeTask();
diff --git a/kig/kig/kig_part.cpp b/kig/kig/kig_part.cpp
index 137d0096..f59559d1 100644
--- a/kig/kig/kig_part.cpp
+++ b/kig/kig/kig_part.cpp
@@ -165,7 +165,7 @@ bool KigPrintDialogPage::isValid( TQString& )
return true;
}
-KigPart::KigPart( TQWidget *tqparentWidget, const char *,
+KigPart::KigPart( TQWidget *parentWidget, const char *,
TQObject *tqparent, const char *name,
const TQStringList& )
: KParts::ReadWritePart( tqparent, name ),
@@ -177,7 +177,7 @@ KigPart::KigPart( TQWidget *tqparentWidget, const char *,
mMode = new NormalMode( *this );
// we need a widget, to actually show the document
- m_widget = new KigView(this, false, tqparentWidget, "kig_view");
+ m_widget = new KigView(this, false, parentWidget, "kig_view");
// notify the part that this is our internal widget
setWidget( m_widget );
diff --git a/kig/kig/kig_part.h b/kig/kig/kig_part.h
index 187f559e..677c9037 100644
--- a/kig/kig/kig_part.h
+++ b/kig/kig/kig_part.h
@@ -66,7 +66,7 @@ public:
/**
* Default constructor
*/
- KigPart( TQWidget* tqparentWidget, const char* widgetName,
+ KigPart( TQWidget* parentWidget, const char* widgetName,
TQObject* tqparent = 0, const char* name = 0,
const TQStringList& = TQStringList()
);
diff --git a/kig/kig/kig_view.h b/kig/kig/kig_view.h
index 4c167d7a..9d3ebab2 100644
--- a/kig/kig/kig_view.h
+++ b/kig/kig/kig_view.h
@@ -235,7 +235,7 @@ class KigView
TQScrollBar* mbottomscroll;
/**
- * aptqparently, TQScrollBar also emits its signals when you update it
+ * apparently, TQScrollBar also emits its signals when you update it
* manually, so we ignore them while we're in \ref updateScrollBars()...
*/
bool mupdatingscrollbars;
diff --git a/kig/misc/argsparser.cpp b/kig/misc/argsparser.cpp
index 9d722752..c2387970 100644
--- a/kig/misc/argsparser.cpp
+++ b/kig/misc/argsparser.cpp
@@ -152,15 +152,15 @@ ArgsParser ArgsParser::without( const ObjectImpType* type ) const
return ArgsParser( ret );
}
-ArgsParser::spec ArgsParser::findSpec( const ObjectImp* obj, const Args& tqparents ) const
+ArgsParser::spec ArgsParser::findSpec( const ObjectImp* obj, const Args& parents ) const
{
spec ret;
ret.type = 0;
std::vector found( margs.size(), false );
- for ( Args::const_iterator o = tqparents.begin();
- o != tqparents.end(); ++o )
+ for ( Args::const_iterator o = parents.begin();
+ o != parents.end(); ++o )
{
for ( uint i = 0; i < margs.size(); ++i )
{
@@ -183,9 +183,9 @@ ArgsParser::spec ArgsParser::findSpec( const ObjectImp* obj, const Args& tqparen
}
const ObjectImpType* ArgsParser::impRequirement(
- const ObjectImp* o, const Args& tqparents ) const
+ const ObjectImp* o, const Args& parents ) const
{
- spec s = findSpec( o, tqparents );
+ spec s = findSpec( o, parents );
return s.type;
}
@@ -233,9 +233,9 @@ ArgsParser::~ArgsParser()
{
}
-bool ArgsParser::isDefinedOnOrThrough( const ObjectImp* o, const Args& tqparents ) const
+bool ArgsParser::isDefinedOnOrThrough( const ObjectImp* o, const Args& parents ) const
{
- spec s = findSpec( o, tqparents );
+ spec s = findSpec( o, parents );
return s.onOrThrough;
}
diff --git a/kig/misc/calcpaths.h b/kig/misc/calcpaths.h
index 3abf19a6..f81ddc09 100644
--- a/kig/misc/calcpaths.h
+++ b/kig/misc/calcpaths.h
@@ -23,7 +23,7 @@
/**
* This function sorts \p os such that they're in the right order for
* calc()-ing. This means that child objects must appear after their
- * tqparents ( for you graph people, this is just a topological sort.. )
+ * parents ( for you graph people, this is just a topological sort.. )
*/
std::vector calcPath( const std::vector& os );
diff --git a/kig/misc/cubic-common.cc b/kig/misc/cubic-common.cc
index 6bdf3aca..029f1194 100644
--- a/kig/misc/cubic-common.cc
+++ b/kig/misc/cubic-common.cc
@@ -486,7 +486,7 @@ const CubicCartesianData calcCubicTransformation (
// assert (fabs(b[0][1][2] - b[1][2][0]) < 1e-8); // test a couple of cases
// assert (fabs(b[0][1][1] - b[1][1][0]) < 1e-8);
- // aptqparently, the above assertions are wrong ( due to rounding
+ // apparently, the above assertions are wrong ( due to rounding
// errors, Maurizio and I hope :) ), so since the symmetry is not
// present, we just take the sum of the parts of the matrix elements
// that should be symmetric, instead of taking one of them, and
diff --git a/kig/misc/object_constructor.cc b/kig/misc/object_constructor.cc
index a5802d45..5522a598 100644
--- a/kig/misc/object_constructor.cc
+++ b/kig/misc/object_constructor.cc
@@ -124,12 +124,12 @@ SimpleObjectTypeConstructor::~SimpleObjectTypeConstructor()
{
}
-void SimpleObjectTypeConstructor::drawprelim( const ObjectDrawer& drawer, KigPainter& p, const std::vector& tqparents,
+void SimpleObjectTypeConstructor::drawprelim( const ObjectDrawer& drawer, KigPainter& p, const std::vector& parents,
const KigDocument& doc ) const
{
Args args;
using namespace std;
- transform( tqparents.begin(), tqparents.end(),
+ transform( parents.begin(), parents.end(),
back_inserter( args ), mem_fun( &ObjectCalcer::imp ) );
ObjectImp* data = mtype->calc( args, doc );
drawer.draw( *data, p, true );
@@ -178,12 +178,12 @@ MultiObjectTypeConstructor::~MultiObjectTypeConstructor()
{
}
-void MultiObjectTypeConstructor::drawprelim( const ObjectDrawer& drawer, KigPainter& p, const std::vector& tqparents,
+void MultiObjectTypeConstructor::drawprelim( const ObjectDrawer& drawer, KigPainter& p, const std::vector& parents,
const KigDocument& doc ) const
{
Args args;
using namespace std;
- transform( tqparents.begin(), tqparents.end(),
+ transform( parents.begin(), parents.end(),
back_inserter( args ), mem_fun( &ObjectCalcer::imp ) );
for ( vector::const_iterator i = mparams.begin(); i != mparams.end(); ++i )
@@ -551,26 +551,26 @@ PropertyObjectConstructor::~PropertyObjectConstructor()
}
void PropertyObjectConstructor::drawprelim(
- const ObjectDrawer& drawer, KigPainter& p, const std::vector& tqparents,
+ const ObjectDrawer& drawer, KigPainter& p, const std::vector& parents,
const KigDocument& d ) const
{
- int index = tqparents[0]->imp()->propertiesInternalNames().tqfindIndex( mpropinternalname );
+ int index = parents[0]->imp()->propertiesInternalNames().tqfindIndex( mpropinternalname );
assert ( index != -1 );
- ObjectImp* imp = tqparents[0]->imp()->property( index, d );
+ ObjectImp* imp = parents[0]->imp()->property( index, d );
drawer.draw( *imp, p, true );
delete imp;
}
std::vector PropertyObjectConstructor::build(
- const std::vector& tqparents, KigDocument&,
+ const std::vector& parents, KigDocument&,
KigWidget& ) const
{
- int index = tqparents[0]->imp()->propertiesInternalNames().tqfindIndex( mpropinternalname );
+ int index = parents[0]->imp()->propertiesInternalNames().tqfindIndex( mpropinternalname );
assert( index != -1 );
std::vector ret;
ret.push_back(
new ObjectHolder(
- new ObjectPropertyCalcer( tqparents[0], index ) ) );
+ new ObjectPropertyCalcer( parents[0], index ) ) );
return ret;
}
diff --git a/kig/misc/object_constructor.h b/kig/misc/object_constructor.h
index 9233426f..9b03ece0 100644
--- a/kig/misc/object_constructor.h
+++ b/kig/misc/object_constructor.h
@@ -165,7 +165,7 @@ public:
const KigDocument& d, const KigWidget& v
) const;
- virtual void drawprelim( const ObjectDrawer& drawer, KigPainter& p, const std::vector& tqparents,
+ virtual void drawprelim( const ObjectDrawer& drawer, KigPainter& p, const std::vector& parents,
const KigDocument& ) const = 0;
TQString useText( const ObjectCalcer& o, const std::vector& sel,
@@ -196,7 +196,7 @@ public:
~SimpleObjectTypeConstructor();
- void drawprelim( const ObjectDrawer& drawer, KigPainter& p, const std::vector& tqparents,
+ void drawprelim( const ObjectDrawer& drawer, KigPainter& p, const std::vector& parents,
const KigDocument& ) const;
std::vector build( const std::vector& os,
@@ -225,7 +225,7 @@ public:
~PropertyObjectConstructor();
- void drawprelim( const ObjectDrawer& drawer, KigPainter& p, const std::vector& tqparents,
+ void drawprelim( const ObjectDrawer& drawer, KigPainter& p, const std::vector& parents,
const KigDocument& ) const;
std::vector build( const std::vector& os,
@@ -265,7 +265,7 @@ public:
int a, int b, int c = -999, int d = -999 );
~MultiObjectTypeConstructor();
- void drawprelim( const ObjectDrawer& drawer, KigPainter& p, const std::vector& tqparents,
+ void drawprelim( const ObjectDrawer& drawer, KigPainter& p, const std::vector& parents,
const KigDocument& ) const;
std::vector build(
diff --git a/kig/filters/native-filter.cc b/kig/filters/native-filter.cc
index 4a3d0a04..9e92130d 100644
--- a/kig/filters/native-filter.cc
+++ b/kig/filters/native-filter.cc
@@ -51,7 +51,7 @@
struct HierElem
{
int id;
- std::vector tqparents;
+ std::vector parents;
TQDomElement el;
};
@@ -73,8 +73,8 @@ static void visitElem( std::vector& ret,
{
if ( !seen[i] )
{
- for ( uint j = 0; j < elems[i].tqparents.size(); ++j )
- visitElem( ret, elems, seen, elems[i].tqparents[j] - 1);
+ for ( uint j = 0; j < elems[i].parents.size(); ++j )
+ visitElem( ret, elems, seen, elems[i].parents[j] - 1);
ret.push_back( elems[i] );
seen[i] = true;
};
@@ -273,7 +273,7 @@ KigDocument* KigFilterNative::load04( const TQString& file, const TQDomElement&
if ( ! ok ) KIG_FILTER_PARSE_ERROR;
extendVect( elems, id );
- elems[id-1].tqparents.push_back( pid );
+ elems[id-1].parents.push_back( pid );
}
}
};
@@ -315,8 +315,8 @@ KigDocument* KigFilterNative::load04( const TQString& file, const TQDomElement&
propname = ec.text().latin1();
};
- if ( i->tqparents.size() != 1 ) KIG_FILTER_PARSE_ERROR;
- ObjectCalcer* tqparent = retcalcers[i->tqparents[0] -1];
+ if ( i->parents.size() != 1 ) KIG_FILTER_PARSE_ERROR;
+ ObjectCalcer* tqparent = retcalcers[i->parents[0] -1];
QCStringList propnames = tqparent->imp()->propertiesInternalNames();
int propid = propnames.tqfindIndex( propname );
if ( propid == -1 )
@@ -342,12 +342,12 @@ KigDocument* KigFilterNative::load04( const TQString& file, const TQDomElement&
return false;
};
- std::vector tqparents;
- for ( std::vector::iterator j = i->tqparents.begin();
- j != i->tqparents.end(); ++j )
- tqparents.push_back( retcalcers[*j - 1] );
+ std::vector parents;
+ for ( std::vector::iterator j = i->parents.begin();
+ j != i->parents.end(); ++j )
+ parents.push_back( retcalcers[*j - 1] );
- o = new ObjectTypeCalcer( type, tqparents );
+ o = new ObjectTypeCalcer( type, parents );
}
else continue;
@@ -434,25 +434,25 @@ KigDocument* KigFilterNative::load07( const TQString& file, const TQDomElement&
uint id = tmp.toInt( &ok );
if ( id <= 0 ) KIG_FILTER_PARSE_ERROR;
- std::vector tqparents;
- for ( TQDomElement tqparentel = e.firstChild().toElement(); ! tqparentel.isNull();
- tqparentel = tqparentel.nextSibling().toElement() )
+ std::vector parents;
+ for ( TQDomElement parentel = e.firstChild().toElement(); ! parentel.isNull();
+ parentel = parentel.nextSibling().toElement() )
{
- if ( tqparentel.tagName() != "Parent" ) continue;
- TQString tmp = tqparentel.attribute( "id" );
- uint tqparentid = tmp.toInt( &ok );
+ if ( parentel.tagName() != "Parent" ) continue;
+ TQString tmp = parentel.attribute( "id" );
+ uint parentid = tmp.toInt( &ok );
if ( ! ok ) KIG_FILTER_PARSE_ERROR;
- if ( tqparentid == 0 || tqparentid > calcers.size() ) KIG_FILTER_PARSE_ERROR;
- ObjectCalcer* tqparent = calcers[tqparentid - 1].get();
+ if ( parentid == 0 || parentid > calcers.size() ) KIG_FILTER_PARSE_ERROR;
+ ObjectCalcer* tqparent = calcers[parentid - 1].get();
if ( ! tqparent ) KIG_FILTER_PARSE_ERROR;
- tqparents.push_back( tqparent );
+ parents.push_back( tqparent );
}
ObjectCalcer* o = 0;
if ( e.tagName() == "Data" )
{
- if ( !tqparents.empty() ) KIG_FILTER_PARSE_ERROR;
+ if ( !parents.empty() ) KIG_FILTER_PARSE_ERROR;
TQString tmp = e.attribute( "type" );
TQString error;
ObjectImp* imp = ObjectImpFactory::instance()->deserialize( tmp, e, error );
@@ -465,10 +465,10 @@ KigDocument* KigFilterNative::load07( const TQString& file, const TQDomElement&
}
else if ( e.tagName() == "Property" )
{
- if ( tqparents.size() != 1 ) KIG_FILTER_PARSE_ERROR;
+ if ( parents.size() != 1 ) KIG_FILTER_PARSE_ERROR;
TQCString propname = e.attribute( "which" ).latin1();
- ObjectCalcer* tqparent = tqparents[0];
+ ObjectCalcer* tqparent = parents[0];
int propid = tqparent->imp()->propertiesInternalNames().tqfindIndex( propname );
if ( propid == -1 ) KIG_FILTER_PARSE_ERROR;
@@ -490,17 +490,17 @@ KigDocument* KigFilterNative::load07( const TQString& file, const TQDomElement&
}
// mp: (I take the responsibility for this!) explanation: the usual ObjectTypeCalcer
// constructor also "sortArgs" the tqparents. I believe that this *must not* be done
// when loading from a saved kig file for the following reasons:
// 1. the arguments should already be in their intended order, since the file was
// saved from a working hierarchy; furthermore we actually want to restore the original
// hierarchy, not really to also fix possible problems with the original hierarchy;
// 2. calling sortArgs could have undesirable side effects in particular situations,
// since kig actually allow an ObjectType to produce different type of ObjectImp's
// it may happen that the tqparents of an object do not satisfy the requirements
// enforced by sortArgs (while moving around the free objects) but still be
// perfectly valid
- o = new ObjectTypeCalcer( type, tqparents, false );
+ o = new ObjectTypeCalcer( type, parents, false );
}
else KIG_FILTER_PARSE_ERROR;
@@ -615,8 +615,8 @@ bool KigFilterNative::save07( const KigDocument& kdoc, TQTextStream& stream )
}
else assert( false );
- const std::vector tqparents = ( *i )->tqparents();
- for ( std::vector::const_iterator i = tqparents.begin(); i != tqparents.end(); ++i )
+ const std::vector parents = ( *i )->parents();
+ for ( std::vector::const_iterator i = parents.begin(); i != parents.end(); ++i )
{
std::map::const_iterator idp = idmap.find( *i );
assert( idp != idmap.end() );
@@ -490,17 +490,17 @@ KigDocument* KigFilterNative::load07( const TQString& file, const TQDomElement&
}
// mp: (I take the responsibility for this!) explanation: the usual ObjectTypeCalcer
- // constructor also "sortArgs" the tqparents. I believe that this *must not* be done
+ // constructor also "sortArgs" the parents. I believe that this *must not* be done
// when loading from a saved kig file for the following reasons:
// 1. the arguments should already be in their intended order, since the file was
@@ -490,17 +490,17 @@ KigDocument* KigFilterNative::load07( const TQString& file, const TQDomElement&
// 2. calling sortArgs could have undesirable side effects in particular situations,
// since kig actually allow an ObjectType to produce different type of ObjectImp's
- // it may happen that the tqparents of an object do not satisfy the requirements
+ // it may happen that the parents of an object do not satisfy the requirements
// enforced by sortArgs (while moving around the free objects) but still be
// perfectly valid
diff --git a/kig/misc/argsparser.h b/kig/misc/argsparser.h
index a3aff562..001d9359 100644
--- a/kig/misc/argsparser.h
+++ b/kig/misc/argsparser.h
@@ -26,7 +26,7 @@ class ObjectImpType;
/**
* This class is meant to take care of checking the types of the
* tqparents to ObjectCalcer's, and to put them in the correct order.
* An ObjectType should construct an ArgsParser with a specification
* of the arguments it wants. This specification is given as an array
* of ArgsParser::spec structs. This struct contains a pointer to an
@@ -117,7 +117,7 @@ private:
*/
std::vector margs;
- spec findSpec( const ObjectImp* o, const Args& tqparents ) const;
+ spec findSpec( const ObjectImp* o, const Args& parents ) const;
public:
ArgsParser( const struct spec* args, int n );
ArgsParser( const std::vector& args );
@@ -137,7 +137,7 @@ public:
int check( const std::vector& os ) const;
/**
* returns the usetext for the argument that o would be used for,
- * if sel were used as tqparents..
+ * if sel were used as parents..
* \p o should be in \p sel ...
*/
std::string usetext( const ObjectImp* o, const Args& sel ) const;
@@ -155,16 +155,16 @@ public:
/**
* returns the minimal ObjectImp ID that \p o needs to inherit in order
* to be useful.. \p o should be part of \p tqparents .
*/
- const ObjectImpType* impRequirement( const ObjectImp* o, const Args& tqparents ) const;
+ const ObjectImpType* impRequirement( const ObjectImp* o, const Args& parents ) const;
/**
* Supposing that \p tqparents would be given as tqparents, this function
* returns whether the returned ObjectImp will be, by construction,
* on \p o ( if \p o is a curve ), or through \p o ( if \p o is a point ).
*/
- bool isDefinedOnOrThrough( const ObjectImp* o, const Args& tqparents ) const;
+ bool isDefinedOnOrThrough( const ObjectImp* o, const Args& parents ) const;
// Checks the args according to this args specification. If the
// objects should never have occurred, then an assertion failure
@@ -26,7 +26,7 @@ class ObjectImpType;
/**
* This class is meant to take care of checking the types of the
- * tqparents to ObjectCalcer's, and to put them in the correct order.
+ * parents to ObjectCalcer's, and to put them in the correct order.
* An ObjectType should construct an ArgsParser with a specification
* of the arguments it wants. This specification is given as an array
@@ -155,16 +155,16 @@ public:
/**
* returns the minimal ObjectImp ID that \p o needs to inherit in order
- * to be useful.. \p o should be part of \p tqparents .
+ * to be useful.. \p o should be part of \p parents .
*/
@@ -155,16 +155,16 @@ public:
/**
- * Supposing that \p tqparents would be given as tqparents, this function
+ * Supposing that \p parents would be given as parents, this function
* returns whether the returned ObjectImp will be, by construction,
* on \p o ( if \p o is a curve ), or through \p o ( if \p o is a point ).
diff --git a/kig/misc/calcpaths.cc b/kig/misc/calcpaths.cc
index 55787518..15dd9d98 100644
--- a/kig/misc/calcpaths.cc
+++ b/kig/misc/calcpaths.cc
@@ -124,7 +124,7 @@ std::vector calcPath( const std::vector& os )
};
// now we know that if all objects appear at least once after all of
// their tqparents. So, we take all, and of every object, we remove
// every reference except the last one...
std::vector ret;
ret.reserve( os.size() );
@@ -182,9 +182,9 @@ static void addNonCache( ObjectCalcer* o, std::vector& ret )
ret.push_back( o );
else
{
- std::vector tqparents = o->tqparents();
- for ( uint i = 0; i < tqparents.size(); ++i )
- addNonCache( tqparents[i], ret );
+ std::vector parents = o->parents();
+ for ( uint i = 0; i < parents.size(); ++i )
+ addNonCache( parents[i], ret );
};
}
@@ -196,13 +196,13 @@ static bool visit( const ObjectCalcer* o, const std::vector& from
// but their direct tqchildren do ), then we add them to ret.
if ( std::find( from.begin(), from.end(), o ) != from.end() ) return true;
- std::vector deps( o->tqparents().size(), false );
+ std::vector deps( o->parents().size(), false );
bool somedepend = false;
bool alldepend = true;
- std::vector tqparents = o->tqparents();
- for ( uint i = 0; i < tqparents.size(); ++i )
+ std::vector parents = o->parents();
+ for ( uint i = 0; i < parents.size(); ++i )
{
- bool v = visit( tqparents[i], from, ret );
+ bool v = visit( parents[i], from, ret );
somedepend |= v;
alldepend &= v;
deps[i] = v;
@@ -211,7 +211,7 @@ static bool visit( const ObjectCalcer* o, const std::vector& from
{
for ( uint i = 0; i < deps.size(); ++i )
if ( ! deps[i] )
- addNonCache( tqparents[i], ret );
+ addNonCache( parents[i], ret );
};
return somedepend;
@@ -234,8 +234,8 @@ std::vector getAllParents( const std::vector& objs
std::set next;
for ( std::set::const_iterator i = cur.begin(); i != cur.end(); ++i )
{
- std::vector tqparents = (*i)->tqparents();
- next.insert( tqparents.begin(), tqparents.end() );
+ std::vector parents = (*i)->parents();
+ next.insert( parents.begin(), parents.end() );
};
ret.insert( next.begin(), next.end() );
@@ -253,16 +253,16 @@ std::vector getAllParents( ObjectCalcer* obj )
bool isChild( const ObjectCalcer* o, const std::vector& os )
{
- std::vector tqparents = o->tqparents();
- std::set cur( tqparents.begin(), tqparents.end() );
+ std::vector parents = o->parents();
+ std::set cur( parents.begin(), parents.end() );
while ( ! cur.empty() )
{
std::set next;
for ( std::set::const_iterator i = cur.begin(); i != cur.end(); ++i )
{
if ( std::find( os.begin(), os.end(), *i ) != os.end() ) return true;
- std::vector tqparents = (*i)->tqparents();
- next.insert( tqparents.begin(), tqparents.end() );
+ std::vector parents = (*i)->parents();
+ next.insert( parents.begin(), parents.end() );
};
cur = next;
};
@@ -124,7 +124,7 @@ std::vector calcPath( const std::vector& os )
};
// now we know that if all objects appear at least once after all of
- // their tqparents. So, we take all, and of every object, we remove
+ // their parents. So, we take all, and of every object, we remove
// every reference except the last one...
std::vector ret;
diff --git a/kig/misc/object_hierarchy.cc b/kig/misc/object_hierarchy.cc
index 7a977e63..264f7e8c 100644
--- a/kig/misc/object_hierarchy.cc
+++ b/kig/misc/object_hierarchy.cc
@@ -47,14 +47,14 @@ public:
// on the given objects. The dependsstack contains a set of
// booleans telling which parts of the hierarchy certainly depend on
// the given objects. In this function, the node should check
// whether any of its tqparents have true set, and if so, set its own
// value to true.
virtual void checkDependsOnGiven( std::vector& dependsstack, int loc ) const = 0;
// this function is used to check whether the given objects are all
// used by one or more of the final objects. The usedstack tqcontains
// a set of booleans telling which parts of the hierarchy are
// certainly ancestors of the final objects. In this function, the
// node should set all of its tqparents' booleans to true.
virtual void checkArgumentsUsed( std::vector& usedstack ) const = 0;
};
@@ -118,15 +118,15 @@ class ApplyTypeNode
: public ObjectHierarchy::Node
{
const ObjectType* mtype;
- std::vector mtqparents;
+ std::vector mparents;
public:
- ApplyTypeNode( const ObjectType* type, const std::vector& tqparents )
- : mtype( type ), mtqparents( tqparents ) {}
+ ApplyTypeNode( const ObjectType* type, const std::vector& parents )
+ : mtype( type ), mparents( parents ) {}
~ApplyTypeNode();
Node* copy() const;
const ObjectType* type() const { return mtype; }
- const std::vector& tqparents() const { return mtqparents; }
+ const std::vector& parents() const { return mparents; }
int id() const;
void apply( std::vector& stack,
@@ -141,17 +141,17 @@ int ApplyTypeNode::id() const { return ID_ApplyType; }
void ApplyTypeNode::checkArgumentsUsed( std::vector& usedstack ) const
{
- for ( uint i = 0; i < mtqparents.size(); ++i )
+ for ( uint i = 0; i < mparents.size(); ++i )
{
- usedstack[mtqparents[i]] = true;
+ usedstack[mparents[i]] = true;
}
}
void ApplyTypeNode::checkDependsOnGiven( std::vector& dependsstack, int loc ) const
{
bool result = false;
- for ( uint i = 0; i < mtqparents.size(); ++i )
- if ( dependsstack[mtqparents[i]] == true ) result = true;
+ for ( uint i = 0; i < mparents.size(); ++i )
+ if ( dependsstack[mparents[i]] == true ) result = true;
dependsstack[loc] = result;
}
@@ -161,23 +161,23 @@ ApplyTypeNode::~ApplyTypeNode()
ObjectHierarchy::Node* ApplyTypeNode::copy() const
{
- return new ApplyTypeNode( mtype, mtqparents );
+ return new ApplyTypeNode( mtype, mparents );
}
void ApplyTypeNode::apply( std::vector& stack, int loc ) const
{
- std::vector tqparents;
- for ( uint i = 0; i < mtqparents.size(); ++i )
- tqparents.push_back( stack[ mtqparents[i] ] );
- stack[loc] = new ObjectTypeCalcer( mtype, tqparents );
+ std::vector parents;
+ for ( uint i = 0; i < mparents.size(); ++i )
+ parents.push_back( stack[ mparents[i] ] );
+ stack[loc] = new ObjectTypeCalcer( mtype, parents );
}
void ApplyTypeNode::apply( std::vector& stack,
int loc, const KigDocument& doc ) const
{
Args args;
- for ( uint i = 0; i < mtqparents.size(); ++i )
- args.push_back( stack[mtqparents[i]] );
+ for ( uint i = 0; i < mparents.size(); ++i )
+ args.push_back( stack[mparents[i]] );
args = mtype->sortArgs( args );
stack[loc] = mtype->calc( args, doc );
}
@@ -297,23 +297,23 @@ int ObjectHierarchy::visit( const ObjectCalcer* o, std::map tqparents;
- tqparents.push_back( smi->second );
- mnodes.push_back( new ApplyTypeNode( CopyObjectType::instance(), tqparents ) );
+ std::vector parents;
+ parents.push_back( smi->second );
+ mnodes.push_back( new ApplyTypeNode( CopyObjectType::instance(), parents ) );
return ret;
}
else return smi->second;
}
- std::vector p( o->tqparents() );
+ std::vector p( o->parents() );
// we check if o descends from the given objects..
bool descendsfromgiven = false;
- std::vector tqparents;
- tqparents.resize( p.size(), -1 );
+ std::vector parents;
+ parents.resize( p.size(), -1 );
for ( uint i = 0; i < p.size(); ++i )
{
int v = visit( p[i], seenmap, false );
- tqparents[i] = v;
+ parents[i] = v;
descendsfromgiven |= (v != -1);
};
@@ -335,7 +335,7 @@ int ObjectHierarchy::visit( const ObjectCalcer* o, std::map& from, const std::v
seenmap[from[i]] = i;
for ( std::vector::const_iterator i = to.begin(); i != to.end(); ++i )
{
- std::vector tqparents = (*i)->tqparents();
- for ( std::vector::const_iterator j = tqparents.begin();
- j != tqparents.end(); ++j )
+ std::vector parents = (*i)->parents();
+ for ( std::vector::const_iterator j = parents.begin();
+ j != parents.end(); ++j )
visit( *j, seenmap, true );
}
for ( std::vector
@@ -47,14 +47,14 @@ public:
// booleans telling which parts of the hierarchy certainly depend on
// the given objects. In this function, the node should check
- // whether any of its tqparents have true set, and if so, set its own
+ // whether any of its parents have true set, and if so, set its own
// value to true.
virtual void checkDependsOnGiven( std::vector& dependsstack, int loc ) const = 0;
@@ -47,14 +47,14 @@ public:
// a set of booleans telling which parts of the hierarchy are
// certainly ancestors of the final objects. In this function, the
- // node should set all of its tqparents' booleans to true.
+ // node should set all of its parents' booleans to true.
virtual void checkArgumentsUsed( std::vector& usedstack ) const = 0;
};